@@ -8,23 +8,25 @@ import (
 
 	"github.com/peterbourgon/ff/v3/ffcli"
 
+	"berty.tech/berty/v2/go/pkg/authtypes"
 	"berty.tech/berty/v2/go/pkg/bertypushrelay"
-	"berty.tech/weshnet/pkg/authtypes"
-	"berty.tech/weshnet/pkg/cryptoutil"
-	"berty.tech/weshnet/pkg/pushtypes"
+	"berty.tech/berty/v2/go/pkg/pushtypes"
+	"berty.tech/weshnet/v2/pkg/cryptoutil"
 )
 
 func pushServerCommand() *ffcli.Command {
 	var (
-		apns *string
-		fcm  *string
-		sk   *string
+		apns         *string
+		fcmBundleIDs *string
+		fcmKeys      *string
+		sk           *string
 	)
 
 	fsBuilder := func() (*flag.FlagSet, error) {
 		fs := flag.NewFlagSet("berty push-server", flag.ExitOnError)
 		apns = fs.String("apns", "", "Apple's apns certs path, comma-separated")
-		fcm = fs.String("fcm", "", "Firebase's FCM API keys, formatted like app_id:api_key and comma-separated")
+		fcmBundleIDs = fs.String("fcm-bundleids", "", "App BundleIDs, comma-separated. Require if the GOOGLE_APPLICATION_CREDENTIALS env var is set for FCM credentials")
+		fcmKeys = fs.String("fcm-keys", "", "Firebase's FCM API keys, formatted like app_id:api_key.json and comma-separated, if the GOOGLE_APPLICATION_CREDENTIALS env var is not set")
 		sk = fs.String("push-private-key", "", "Push server private key, base64 formatted")
 		manager.SetupLoggingFlags(fs) // also available at root level
 		manager.SetupProtocolAuth(fs)
@@ -82,7 +84,7 @@ func pushServerCommand() *ffcli.Command {
 
 			dispatchers = append(dispatchers, apnsDispatchers...)
 
-			fcmDispatchers, err := bertypushrelay.PushDispatcherLoadFirebaseAPIKey(logger, fcm)
+			fcmDispatchers, err := bertypushrelay.PushDispatcherLoadFirebaseAPIKey(ctx, logger, fcmBundleIDs, fcmKeys)
 			if err != nil {
 				return err
 			}
@@ -104,7 +106,7 @@ func pushServerCommand() *ffcli.Command {
 				return err
 			}
 
-			return manager.RunWorkers()
+			return manager.RunWorkers(ctx)
 		},
 	}
 }
