@@ -7,9 +7,9 @@ import (
 
 	"github.com/peterbourgon/ff/v3/ffcli"
 
+	"berty.tech/berty/v2/go/pkg/authtypes"
 	"berty.tech/berty/v2/go/pkg/bertyreplication"
-	"berty.tech/weshnet/pkg/authtypes"
-	"berty.tech/weshnet/pkg/replicationtypes"
+	"berty.tech/weshnet/v2/pkg/replicationtypes"
 )
 
 func replicationServerCommand() *ffcli.Command {
@@ -78,7 +78,7 @@ func replicationServerCommand() *ffcli.Command {
 				return err
 			}
 
-			return manager.RunWorkers()
+			return manager.RunWorkers(ctx)
 		},
 	}
 }
