@@ -6,7 +6,7 @@ import (
 	"encoding/json"
 	"flag"
 	"fmt"
-	"math/rand"
+	mrand "math/rand"
 	"os"
 	"os/signal"
 	"os/user"
@@ -15,13 +15,12 @@ import (
 	"sync"
 	"time"
 
-	"github.com/gogo/protobuf/proto"
 	qrterminal "github.com/mdp/qrterminal/v3"
 	"go.uber.org/zap"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/connectivity"
 	"google.golang.org/grpc/credentials/insecure"
-	"moul.io/srand"
+	"google.golang.org/protobuf/proto"
 	"moul.io/u"
 	"moul.io/zapconfig"
 
@@ -103,10 +102,11 @@ func welcomebot() error {
 	defer cancel()
 
 	flag.Parse()
-	rand.Seed(srand.MustSecure())
 
 	// init bot
-	bot := &Bot{storeConvMap: make(map[*Conversation]*sync.Mutex)}
+	bot := &Bot{
+		storeConvMap: make(map[*Conversation]*sync.Mutex),
+	}
 
 	// init logger
 	{
@@ -150,7 +150,7 @@ func welcomebot() error {
 
 	// init messenger gRPC client
 	{
-		cc, err := grpc.DialContext(ctx, *nodeAddr, grpc.WithTransportCredentials(insecure.NewCredentials()))
+		cc, err := grpc.NewClient(*nodeAddr, grpc.WithTransportCredentials(insecure.NewCredentials()))
 		if err != nil {
 			return fmt.Errorf("unable to connect with remote berty messenger node: %w", err)
 		}
@@ -181,8 +181,8 @@ func welcomebot() error {
 		if err != nil {
 			return fmt.Errorf("get instance shareable berty ID failed: %w", err)
 		}
-		bot.logger.Info("retrieve instance Berty ID", zap.String("link", res.WebURL))
-		qrterminal.GenerateHalfBlock(res.InternalURL, qrterminal.L, os.Stdout)
+		bot.logger.Info("retrieve instance Berty ID", zap.String("link", res.WebUrl))
+		qrterminal.GenerateHalfBlock(res.InternalUrl, qrterminal.L, os.Stdout)
 	}
 
 	// join staff conversation
@@ -303,13 +303,14 @@ func (bot *Bot) handleContactUpdated(ctx context.Context, _ *messengertypes.Even
 	// auto-accept contact requests
 	contact := payload.(*messengertypes.StreamEvent_ContactUpdated).Contact
 
-	if contact.State == messengertypes.Contact_IncomingRequest {
+	switch contact.State {
+	case messengertypes.Contact_IncomingRequest:
 		req := &messengertypes.ContactAccept_Request{PublicKey: contact.PublicKey}
 		_, err := bot.client.ContactAccept(ctx, req)
 		if err != nil {
 			return fmt.Errorf("contact accept failed: %w", err)
 		}
-	} else if contact.State == messengertypes.Contact_Accepted {
+	case messengertypes.Contact_Accepted:
 		// When contact was established, send message and a group invitation
 		time.Sleep(2 * time.Second)
 		bot.storeMutex.Lock()
@@ -674,5 +675,5 @@ func getRandomReply() string {
 		"May we have a chat about our love relationship future ?",
 		"That's cool. I copy.",
 	}
-	return available[rand.Intn(len(available))] // nolint:gosec // absolutely no importance in this case
+	return available[mrand.Intn(len(available))] // nolint:gosec // absolutely no importance in this case
 }
