@@ -20,7 +20,7 @@ import (
 	"moul.io/u"
 
 	"berty.tech/berty/v2/go/internal/initutil"
-	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/v2/pkg/protocoltypes"
 )
 
 func verifySetupLeakDetection(t *testing.T) {
@@ -46,23 +46,26 @@ func verifyRunningLeakDetection(t *testing.T) {
 	// sometimes if timeout is quite short - not enough for below functions to finished
 	time.Sleep(5 * time.Second)
 	goleak.VerifyNone(t,
-		goleak.IgnoreTopFunction("berty.tech/weshnet/pkg/tinder.(*Service).fadeIn"),                                          // ignore this since it is used by the DHT in the background
-		goleak.IgnoreTopFunction("github.com/desertbit/timer.timerRoutine"),                                                  // called by init() in github.com/desertbit/timer/timers.go, refer in grpc-web
-		goleak.IgnoreTopFunction("github.com/ipfs/go-log/writer.(*MirrorWriter).logRoutine"),                                 // global writer created at github.com/ipfs/go-log@v1.0.4/writer/option.go, refer by github.com/ipfs/, like go-bitswap
-		goleak.IgnoreTopFunction("github.com/jbenet/goprocess.(*process).doClose"),                                           // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/jbenet/goprocess/context.CloseAfterContext.func1"),                              // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("github.com/jbenet/goprocess/periodic.callOnTicker.func1"),                                  // FIXME - upstream code - is used in many code of libp2p + go-ipfs
-		goleak.IgnoreTopFunction("github.com/libp2p/go-flow-metrics.(*sweeper).run"),                                         // this goroutine has run always without stop
-		goleak.IgnoreTopFunction("github.com/libp2p/go-flow-metrics.(*sweeper).runActive"),                                   // this goroutine has run always without stop                                       // upstream issue
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/host/peerstore/pstoremem.(*memoryAddrBook).background"),    // upstream issue, no store close in upstream code
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/swarm.(*DialBackoff).background"),                      // the cleanup take too much time, should be managed by ipfs
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/swarm.(*activeDial).dial"),                             // the cleanup take too much time, should be managed by ipfs
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/upgrader.(*Upgrader).setupMuxer"),                      // the closing routine has big timeout
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/upgrader.(*listener).Accept"),                          // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("berty.tech/weshnet/pkg/ipfsutil.(*mdnsService).startResolver.func1"),                       // upstream issue of mdns, go wakeup periodiclly to do action before check exist, timeout about 10 seconds
-		goleak.IgnoreTopFunction("github.com/lucas-clemente/quic-go.(*packetHandlerMap).runCloseQueue"),                      // quic-go should be manager by libp2p
-		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/transport/quicreuse.(*reuse).gc"),                          // managed by ipfs
-		goleak.IgnoreTopFunction("github.com/quic-go/quic-go.(*packetHandlerMap).runCloseQueue"),                             // managed by ipfs
+		goleak.IgnoreTopFunction("berty.tech/weshnet/v2/pkg/tinder.(*Service).fadeIn"),                                    // ignore this since it is used by the DHT in the background
+		goleak.IgnoreTopFunction("github.com/desertbit/timer.timerRoutine"),                                               // called by init() in github.com/desertbit/timer/timers.go, refer in grpc-web
+		goleak.IgnoreTopFunction("github.com/ipfs/go-log/writer.(*MirrorWriter).logRoutine"),                              // global writer created at github.com/ipfs/go-log@v1.0.4/writer/option.go, refer by github.com/ipfs/, like go-bitswap
+		goleak.IgnoreTopFunction("github.com/jbenet/goprocess.(*process).doClose"),                                        // sometimes happening on CI, need more investigation
+		goleak.IgnoreTopFunction("github.com/jbenet/goprocess/context.CloseAfterContext.func1"),                           // sometimes happening on CI, need more investigation
+		goleak.IgnoreTopFunction("github.com/jbenet/goprocess/periodic.callOnTicker.func1"),                               // FIXME - upstream code - is used in many code of libp2p + go-ipfs
+		goleak.IgnoreTopFunction("github.com/libp2p/go-flow-metrics.(*sweeper).run"),                                      // this goroutine has run always without stop
+		goleak.IgnoreTopFunction("github.com/libp2p/go-flow-metrics.(*sweeper).runActive"),                                // this goroutine has run always without stop                                       // upstream issue
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/host/peerstore/pstoremem.(*memoryAddrBook).background"), // upstream issue, no store close in upstream code
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/swarm.(*DialBackoff).background"),                   // the cleanup take too much time, should be managed by ipfs
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/swarm.(*activeDial).dial"),                          // the cleanup take too much time, should be managed by ipfs
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/upgrader.(*Upgrader).setupMuxer"),                   // the closing routine has big timeout
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/net/upgrader.(*listener).Accept"),                       // sometimes happening on CI, need more investigation
+		goleak.IgnoreTopFunction("berty.tech/weshnet/v2/pkg/ipfsutil.(*mdnsService).startResolver.func1"),                 // upstream issue of mdns, go wakeup periodiclly to do action before check exist, timeout about 10 seconds
+		goleak.IgnoreTopFunction("github.com/lucas-clemente/quic-go.(*packetHandlerMap).runCloseQueue"),                   // quic-go should be manager by libp2p
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/transport/quicreuse.(*reuse).gc"),                       // managed by ipfs
+		goleak.IgnoreTopFunction("github.com/quic-go/quic-go.(*packetHandlerMap).runCloseQueue"),                          // managed by ipfs
+		goleak.IgnoreTopFunction("github.com/quic-go/quic-go.(*Transport).runSendQueue"),
+		goleak.IgnoreTopFunction("github.com/ipfs/boxo/bootstrap.startSavePeersAsTemporaryBootstrapProc.func2"),
+		goleak.IgnoreTopFunction("github.com/ipfs/boxo/bootstrap.peersConnect.func1"),
 		goleak.IgnoreTopFunction("net/http.(*persistConn).writeLoop"),                                                        // managed by ipfs
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/transport/quic.(*reuse).gc"),                               // quic-go should be manager by libp2p
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/host/basic.(*BasicHost).background"),                       // sometimes happening on CI, need more investigation
@@ -76,15 +79,19 @@ func verifyRunningLeakDetection(t *testing.T) {
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/discovery/mdns_legacy.(*mdnsService).startResolver.func1"), // the closing routine has big timeout, should be managed by ipfs
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p/p2p/discovery/mdns.(*mdnsService).startResolver.func1"),        // the closing routine has big timeout, should be managed by ipfs
 		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-kad-dht/providers.(*ProviderManager).GetProviders"),            // the closing routine has big timeout, should be managed by ipfs
-		goleak.IgnoreTopFunction("github.com/libp2p/zeroconf/v2.(*client).mainloop"),                                         // the closing routine has big timeout, should be managed by ipfs
-		goleak.IgnoreTopFunction("github.com/libp2p/zeroconf/v2.(*client).periodicQuery"),                                    // the closing routine has big timeout, should be managed by ipfs
-		goleak.IgnoreTopFunction("github.com/ipfs/kubo/core/bootstrap.bootstrapConnect.func1 "),                              // the closing routine has big timeout, should be managed by ipfs
-		goleak.IgnoreTopFunction("go.opencensus.io/stats/view.(*worker).start"),                                              // called by init() in berty/go/internal/grpcutil/server.go
-		goleak.IgnoreTopFunction("go.uber.org/fx.withTimeout"),                                                               // sometimes happening on CI, need more investigation
-		goleak.IgnoreTopFunction("internal/poll.runtime_pollWait"),                                                           // upstream issue of mdns, go wakeup periodiclly to do action before check exist, timeout about 10 seconds
-		goleak.IgnoreTopFunction("net.(*netFD).connect.func2"),                                                               // FIXME - many libraries used this code
-		goleak.IgnoreTopFunction("sync.runtime_Semacquire"),                                                                  // the closing routine has big timeout
-		goleak.IgnoreTopFunction("sync.runtime_SemacquireMutex"),                                                             // sometimes happening on CI, need more investigation
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-kad-dht/dual.(*DHT).FindProvidersAsync.func1"),
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-kad-dht/dual.(*DHT).FindProvidersAsync.func2"),
+		goleak.IgnoreTopFunction("github.com/libp2p/zeroconf/v2.(*client).mainloop"),            // the closing routine has big timeout, should be managed by ipfs
+		goleak.IgnoreTopFunction("github.com/libp2p/zeroconf/v2.(*client).periodicQuery"),       // the closing routine has big timeout, should be managed by ipfs
+		goleak.IgnoreTopFunction("github.com/ipfs/kubo/core/bootstrap.bootstrapConnect.func1 "), // the closing routine has big timeout, should be managed by ipfs
+		goleak.IgnoreTopFunction("go.opencensus.io/stats/view.(*worker).start"),                 // called by init() in berty/go/internal/grpcutil/server.go
+		goleak.IgnoreTopFunction("go.uber.org/fx.withTimeout"),                                  // sometimes happening on CI, need more investigation
+		goleak.IgnoreTopFunction("internal/poll.runtime_pollWait"),                              // upstream issue of mdns, go wakeup periodiclly to do action before check exist, timeout about 10 seconds
+		goleak.IgnoreTopFunction("net.(*netFD).connect.func2"),                                  // FIXME - many libraries used this code
+		goleak.IgnoreTopFunction("sync.runtime_Semacquire"),                                     // the closing routine has big timeout
+		goleak.IgnoreTopFunction("sync.runtime_SemacquireMutex"),                                // sometimes happening on CI, need more investigation
+		goleak.IgnoreTopFunction("net.(*Resolver).lookupIPAddr"),
+		goleak.IgnoreTopFunction("github.com/libp2p/go-libp2p-kad-dht.(*query).run"),
 	)
 }
 
@@ -154,14 +161,16 @@ func Example_noflags() {
 	}
 
 	// check that the reply is valid (cannot check hardcoded value, since it's random)
-	fmt.Println(ret.AccountPK != nil)
+	fmt.Println(ret.AccountPk != nil)
 
 	// Output:
-	// go-libp2p resource manager protection disabled
 	// true
 }
 
 func TestTwoConcurrentManagers(t *testing.T) {
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
 	var man1, man2 *initutil.Manager
 
 	// FIXME: automatically find an available port
@@ -202,7 +211,7 @@ func TestTwoConcurrentManagers(t *testing.T) {
 		require.NoError(t, err)
 		require.NotNil(t, server)
 
-		go man1.RunWorkers()
+		go man1.RunWorkers(ctx)
 		time.Sleep(time.Second * 2)
 	}
 
@@ -215,7 +224,7 @@ func TestTwoConcurrentManagers(t *testing.T) {
 		ctx := context.Background()
 		ret, err := client.ServiceGetConfiguration(ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 		require.NoError(t, err)
-		require.NotNil(t, ret.AccountPK)
+		require.NotNil(t, ret.AccountPk)
 	}
 }
 
@@ -262,7 +271,7 @@ func TestLocalProtocolServerAndClient(t *testing.T) {
 
 	ret, err := client.ServiceGetConfiguration(ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 	require.NoError(t, err)
-	require.NotNil(t, ret.AccountPK)
+	require.NotNil(t, ret.AccountPk)
 }
 
 func TestLocalProtocolServerLeak(t *testing.T) {
