@@ -5,12 +5,12 @@ import (
 	"testing"
 	"time"
 
-	sqlite "github.com/flyingtime/gorm-sqlcipher"
 	"go.uber.org/zap"
 	"gorm.io/gorm"
 	"moul.io/zapgorm2"
 
-	"berty.tech/weshnet/pkg/testutil"
+	sqlite "berty.tech/berty/v2/go/internal/gorm-sqlcipher"
+	"berty.tech/weshnet/v2/pkg/testutil"
 )
 
 type GetInMemoryTestDBOpts int32
@@ -68,6 +68,8 @@ func GetInMemoryTestDB(t testing.TB, opts ...GetInMemoryTestDBOpts) (*DBWrapper,
 		t.Fatal(err)
 	}
 
+	d.SetMaxOpenConns(1)
+
 	return wrappedDB, db, func() {
 		_ = d.Close()
 		loggerCleanup()
