@@ -1,7 +1,7 @@
 package messengerutil
 
 import (
-	"github.com/gogo/protobuf/proto"
+	"google.golang.org/protobuf/proto"
 
 	"berty.tech/berty/v2/go/pkg/errcode"
 	mt "berty.tech/berty/v2/go/pkg/messengertypes"
@@ -20,7 +20,7 @@ type AugmentedInteractionFetcher interface {
 func StreamInteraction(dispatcher Dispatcher, db AugmentedInteractionFetcher, cid string, isNew bool) error {
 	interaction, err := db.GetAugmentedInteraction(cid)
 	if err != nil {
-		return errcode.ErrDBRead.Wrap(err)
+		return errcode.ErrCode_ErrDBRead.Wrap(err)
 	}
 
 	if err := dispatcher.StreamEvent(
@@ -28,7 +28,7 @@ func StreamInteraction(dispatcher Dispatcher, db AugmentedInteractionFetcher, ci
 		&mt.StreamEvent_InteractionUpdated{Interaction: interaction},
 		isNew,
 	); err != nil {
-		return errcode.ErrMessengerStreamEvent.Wrap(err)
+		return errcode.ErrCode_ErrMessengerStreamEvent.Wrap(err)
 	}
 
 	return nil
@@ -36,10 +36,12 @@ func StreamInteraction(dispatcher Dispatcher, db AugmentedInteractionFetcher, ci
 
 type NoopDispatcher struct{}
 
+//nolint:revive
 func (*NoopDispatcher) StreamEvent(typ mt.StreamEvent_Type, msg proto.Message, isNew bool) error {
 	return nil
 }
 
+//nolint:revive
 func (*NoopDispatcher) Notify(typ mt.StreamEvent_Notified_Type, title, body string, msg proto.Message) error {
 	return nil
 }
