@@ -5,7 +5,7 @@ import (
 
 	"go.uber.org/zap"
 
-	"berty.tech/weshnet/pkg/logutil"
+	"berty.tech/weshnet/v2/pkg/logutil"
 )
 
 // LoggerManager is a Manager
