@@ -8,7 +8,7 @@ import (
 
 	"go.uber.org/multierr"
 
-	"berty.tech/weshnet/pkg/protocoltypes"
+	"berty.tech/weshnet/v2/pkg/protocoltypes"
 )
 
 func appendCustomSystemInfo(reply *protocoltypes.SystemInfo_Process) error {
@@ -25,8 +25,8 @@ func appendCustomSystemInfo(reply *protocoltypes.SystemInfo_Process) error {
 	rusage := syscall.Rusage{}
 	err = syscall.Getrusage(syscall.RUSAGE_SELF, &rusage)
 	errs = multierr.Append(errs, err)
-	reply.UserCPUTimeMS = int64(rusage.Utime.Sec*1000) + int64(rusage.Utime.Usec/1000)   // nolint:unconvert // on some archs, those vars may be int32 instead of int64
-	reply.SystemCPUTimeMS = int64(rusage.Stime.Sec*1000) + int64(rusage.Stime.Usec/1000) // nolint:unconvert // on some archs, those vars may be int32 instead of int64
+	reply.UserCpuTimeMs = int64(rusage.Utime.Sec*1000) + int64(rusage.Utime.Usec/1000)   // nolint:unconvert // on some archs, those vars may be int32 instead of int64
+	reply.SystemCpuTimeMs = int64(rusage.Stime.Sec*1000) + int64(rusage.Stime.Usec/1000) // nolint:unconvert // on some archs, those vars may be int32 instead of int64
 
 	// process priority
 	prio, err := syscall.Getpriority(syscall.PRIO_PROCESS, 0)
