@@ -3,7 +3,7 @@
 
 package sysutil
 
-import "berty.tech/weshnet/pkg/protocoltypes"
+import "berty.tech/weshnet/v2/pkg/protocoltypes"
 
 func appendCustomSystemInfo(reply *protocoltypes.SystemInfo_Process) error {
 	return nil
