@@ -18,8 +18,6 @@ import (
 	// required for dev
 	_ "github.com/githubnemo/CompileDaemon"
 	// required by protoc
-	_ "github.com/gogo/protobuf/gogoproto"
-	// required by protoc
 	_ "github.com/gogo/protobuf/proto"
 	// required by protoc
 	_ "github.com/gogo/protobuf/protoc-gen-gogo"
@@ -35,6 +33,8 @@ import (
 	_ "github.com/mdomke/git-semver/v5"
 	// required by protoc
 	_ "github.com/pseudomuto/protoc-gen-doc/cmd/protoc-gen-doc"
+	// required by protoc
+	_ "github.com/srikrsna/protoc-gen-gotag"
 	// required by Makefile
 	_ "github.com/tailscale/depaware"
 	// required by gomobile
