@@ -21,15 +21,16 @@ import (
 	"berty.tech/berty/v2/go/pkg/bertybridge"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
+	"berty.tech/berty/v2/go/pkg/pushtypes"
 	encrepo "berty.tech/go-ipfs-repo-encrypted"
-	"berty.tech/weshnet/pkg/androidnearby"
-	"berty.tech/weshnet/pkg/lifecycle"
-	"berty.tech/weshnet/pkg/logutil"
-	mc "berty.tech/weshnet/pkg/multipeer-connectivity-driver"
-	"berty.tech/weshnet/pkg/netmanager"
-	"berty.tech/weshnet/pkg/protocoltypes"
-	proximity "berty.tech/weshnet/pkg/proximitytransport"
-	"berty.tech/weshnet/pkg/tyber"
+	"berty.tech/weshnet/v2/pkg/androidnearby"
+	"berty.tech/weshnet/v2/pkg/lifecycle"
+	"berty.tech/weshnet/v2/pkg/logutil"
+	mc "berty.tech/weshnet/v2/pkg/multipeer-connectivity-driver"
+	"berty.tech/weshnet/v2/pkg/netmanager"
+	"berty.tech/weshnet/v2/pkg/protocoltypes"
+	proximity "berty.tech/weshnet/v2/pkg/proximitytransport"
+	"berty.tech/weshnet/v2/pkg/tyber"
 )
 
 // Servicex is AccountServiceServer
@@ -90,7 +91,7 @@ type service struct {
 	bleDriver         proximity.ProximityDriver
 	nbDriver          proximity.ProximityDriver
 	devicePushKeyPath string
-	pushPlatformToken *protocoltypes.PushServiceReceiver
+	pushPlatformToken *pushtypes.PushServiceReceiver
 	accountData       *accounttypes.AccountMetadata
 	nativeKeystore    accountutils.NativeKeystore
 	appStorage        datastore.Datastore
@@ -170,40 +171,40 @@ func NewService(opts *Options) (_ Service, err error) {
 		Logger:         s.logger,
 		NativeKeystore: s.nativeKeystore,
 	}); err != nil {
-		return nil, errcode.TODO.Wrap(err)
+		return nil, errcode.ErrCode_TODO.Wrap(err)
 	}
 
 	// init app storage
 	dbPath := filepath.Join(s.appRootDir, "app.sqlite")
 	if err := os.MkdirAll(s.appRootDir, 0o700); err != nil {
-		return nil, errcode.TODO.Wrap(err)
+		return nil, errcode.ErrCode_TODO.Wrap(err)
 	}
 	storageKey := ([]byte)(nil)
 	if s.nativeKeystore != nil {
 		storageKey, err = accountutils.GetOrCreateMasterStorageKey(s.nativeKeystore)
 		if err != nil {
-			return nil, errcode.TODO.Wrap(err)
+			return nil, errcode.ErrCode_TODO.Wrap(err)
 		}
 	}
 	storageSalt := ([]byte)(nil)
 	if s.nativeKeystore != nil {
 		storageSalt, err = accountutils.GetOrCreateGlobalAppStorageSalt(s.nativeKeystore)
 		if err != nil {
-			return nil, errcode.TODO.Wrap(err)
+			return nil, errcode.ErrCode_TODO.Wrap(err)
 		}
 	}
 	sqldsOpts := encrepo.SQLCipherDatastoreOptions{JournalMode: "WAL", PlaintextHeader: len(storageSalt) != 0, Salt: storageSalt}
 	appDatastore, err := encrepo.NewSQLCipherDatastore("sqlite3", dbPath, "data", storageKey, sqldsOpts)
 	if err != nil {
-		return nil, errcode.ErrDBOpen.Wrap(err)
+		return nil, errcode.ErrCode_ErrDBOpen.Wrap(err)
 	}
 	s.appStorage = encrepo.NewNamespacedDatastore(appDatastore, datastore.NewKey("app-storage"))
 
 	return s, nil
 }
 
-func (s *service) NetworkConfigGetPreset(ctx context.Context, req *accounttypes.NetworkConfigGetPreset_Request) (*accounttypes.NetworkConfigGetPreset_Reply, error) {
-	if req.Preset == accounttypes.NetworkConfigPreset_NetPresetPerformance || req.Preset == accounttypes.NetworkConfigPreset_NetPresetUndefined {
+func (s *service) NetworkConfigGetPreset(_ context.Context, req *accounttypes.NetworkConfigGetPreset_Request) (*accounttypes.NetworkConfigGetPreset_Reply, error) {
+	if req.Preset == accounttypes.NetworkConfigPreset_Performance || req.Preset == accounttypes.NetworkConfigPreset_Undefined {
 		bluetoothLE := accounttypes.NetworkConfig_Disabled
 		if req.HasBluetoothPermission {
 			bluetoothLE = accounttypes.NetworkConfig_Enabled
@@ -223,15 +224,15 @@ func (s *service) NetworkConfigGetPreset(ctx context.Context, req *accounttypes.
 			Config: &accounttypes.NetworkConfig{
 				Bootstrap:                    []string{initutil.KeywordDefault},
 				AndroidNearby:                androidNearby,
-				DHT:                          accounttypes.NetworkConfig_DHTClient,
+				Dht:                          accounttypes.NetworkConfig_DHTClient,
 				AppleMultipeerConnectivity:   appleMC,
-				BluetoothLE:                  bluetoothLE,
-				MDNS:                         accounttypes.NetworkConfig_Enabled,
+				BluetoothLe:                  bluetoothLE,
+				Mdns:                         accounttypes.NetworkConfig_Enabled,
 				Rendezvous:                   []string{initutil.KeywordDefault},
 				Tor:                          accounttypes.NetworkConfig_TorOptional,
 				StaticRelay:                  []string{initutil.KeywordDefault},
 				ShowDefaultServices:          accounttypes.NetworkConfig_Enabled,
-				AllowUnsecureGRPCConnections: accounttypes.NetworkConfig_Disabled,
+				AllowUnsecureGrpcConnections: accounttypes.NetworkConfig_Disabled,
 			},
 		}, nil
 	}
@@ -240,15 +241,15 @@ func (s *service) NetworkConfigGetPreset(ctx context.Context, req *accounttypes.
 		Config: &accounttypes.NetworkConfig{
 			Bootstrap:                    []string{initutil.KeywordNone},
 			AndroidNearby:                accounttypes.NetworkConfig_Disabled,
-			DHT:                          accounttypes.NetworkConfig_DHTDisabled,
+			Dht:                          accounttypes.NetworkConfig_DHTDisabled,
 			AppleMultipeerConnectivity:   accounttypes.NetworkConfig_Disabled,
-			BluetoothLE:                  accounttypes.NetworkConfig_Disabled,
-			MDNS:                         accounttypes.NetworkConfig_Disabled,
+			BluetoothLe:                  accounttypes.NetworkConfig_Disabled,
+			Mdns:                         accounttypes.NetworkConfig_Disabled,
 			Rendezvous:                   []string{initutil.KeywordNone},
 			Tor:                          accounttypes.NetworkConfig_TorDisabled,
 			StaticRelay:                  []string{initutil.KeywordNone},
 			ShowDefaultServices:          accounttypes.NetworkConfig_Disabled,
-			AllowUnsecureGRPCConnections: accounttypes.NetworkConfig_Disabled,
+			AllowUnsecureGrpcConnections: accounttypes.NetworkConfig_Disabled,
 		},
 	}, nil
 }
