@@ -35,6 +35,7 @@ const (
 	// specialized events
 
 	IncomingContactRequestHandler
+	IncomingGroupInvitationHandler
 	AcceptedContactHandler
 	UserMessageHandler
 	NewConversationHandler
@@ -105,6 +106,8 @@ func (b *Bot) handleEvent(ctx context.Context, event *messengertypes.StreamEvent
 				}
 			}
 			b.callHandlers(context, UserMessageHandler)
+		case messengertypes.AppMessage_TypeGroupInvitation:
+			b.callHandlers(context, IncomingGroupInvitationHandler)
 		default:
 			return fmt.Errorf("unsupported interaction type: %q", context.Interaction.Type)
 		}
@@ -169,10 +172,10 @@ func (b *Bot) callHandlers(context *Context, typ HandlerType) {
 		return
 	}
 
-	copy := *context
+	copied := *context
 	for _, handler := range handlers {
-		copy.HandlerType = typ
-		handler(copy)
+		copied.HandlerType = typ
+		handler(copied)
 	}
 }
 
