@@ -4,36 +4,39 @@ import (
 	"archive/tar"
 	"bytes"
 	"context"
-	"encoding/base64"
 	"errors"
 	"fmt"
 	"io"
 	"sync"
+	"sync/atomic"
 	"time"
 
-	sqlite "github.com/flyingtime/gorm-sqlcipher"
-	// nolint:staticcheck // cannot use the new protobuf API while keeping gogoproto
-	"github.com/golang/protobuf/proto"
-	ipfs_interface "github.com/ipfs/interface-go-ipfs-core"
+	ipfs_interface "github.com/ipfs/kubo/core/coreiface"
 	"go.uber.org/zap"
+	"google.golang.org/grpc"
+	"google.golang.org/protobuf/proto"
 	"gorm.io/gorm"
 	"moul.io/u"
 	"moul.io/zapgorm2"
 	"moul.io/zapring"
 
+	"berty.tech/berty/v2/go/internal/dbfetcher"
+	sqlite "berty.tech/berty/v2/go/internal/gorm-sqlcipher"
 	"berty.tech/berty/v2/go/internal/messengerdb"
 	"berty.tech/berty/v2/go/internal/messengerpayloads"
 	"berty.tech/berty/v2/go/internal/messengerutil"
 	"berty.tech/berty/v2/go/internal/notification"
+	"berty.tech/berty/v2/go/pkg/bertypush"
 	"berty.tech/berty/v2/go/pkg/bertyversion"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	mt "berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/weshnet"
-	weshnet_errcode "berty.tech/weshnet/pkg/errcode"
-	"berty.tech/weshnet/pkg/lifecycle"
-	"berty.tech/weshnet/pkg/logutil"
-	"berty.tech/weshnet/pkg/protocoltypes"
-	"berty.tech/weshnet/pkg/tyber"
+	"berty.tech/berty/v2/go/pkg/pushtypes"
+	"berty.tech/weshnet/v2"
+	"berty.tech/weshnet/v2/pkg/cryptoutil"
+	"berty.tech/weshnet/v2/pkg/lifecycle"
+	"berty.tech/weshnet/v2/pkg/logutil"
+	"berty.tech/weshnet/v2/pkg/protocoltypes"
+	"berty.tech/weshnet/v2/pkg/tyber"
 )
 
 type Service interface {
@@ -59,6 +62,10 @@ type service struct {
 	lcmanager             *lifecycle.Manager
 	eventHandler          *messengerpayloads.EventHandler
 	ring                  *zapring.Core
+	pushReceiver          bertypush.MessengerPushReceiver
+	pushHandler           bertypush.PushHandler
+	pushClients           map[string]*grpc.ClientConn
+	muPushClients         sync.RWMutex
 	tyberCleanup          func()
 	logFilePath           string
 	cancelGroupStatus     map[string] /*groupPK */ context.CancelFunc
@@ -72,7 +79,7 @@ type service struct {
 	accountGroup          []byte
 	grpcInsecure          bool
 	dd                    debugCommand
-	// pushReceiver          bertypush.MessengerPushReceiver // FIXME(push): unavailable
+	authSession           atomic.Value
 
 	mt.UnimplementedMessengerServiceServer
 }
@@ -84,7 +91,8 @@ type Opts struct {
 	NotificationManager notification.Manager
 	LifeCycleManager    *lifecycle.Manager
 	StateBackup         *mt.LocalDatabaseState
-	PlatformPushToken   *protocoltypes.PushServiceReceiver
+	PushKey             *[cryptoutil.KeySize]byte
+	PlatformPushToken   *pushtypes.PushServiceReceiver
 	Ring                *zapring.Core
 	GRPCInsecureMode    bool
 
@@ -141,15 +149,15 @@ func databaseStateRestoreAccountHandler(statePointer *mt.LocalDatabaseState) wes
 			backupContents := new(bytes.Buffer)
 			size, err := io.Copy(backupContents, reader)
 			if err != nil {
-				return true, errcode.ErrInternal.Wrap(fmt.Errorf("unable to read %d bytes: %w", header.Size, err))
+				return true, errcode.ErrCode_ErrInternal.Wrap(fmt.Errorf("unable to read %d bytes: %w", header.Size, err))
 			}
 
 			if size != header.Size {
-				return true, errcode.ErrInternal.Wrap(fmt.Errorf("unexpected file size"))
+				return true, errcode.ErrCode_ErrInternal.Wrap(fmt.Errorf("unexpected file size"))
 			}
 
 			if err := proto.Unmarshal(backupContents.Bytes(), statePointer); err != nil {
-				return true, errcode.ErrDeserialization.Wrap(err)
+				return true, errcode.ErrCode_ErrDeserialization.Wrap(err)
 			}
 
 			return true, nil
@@ -167,7 +175,7 @@ func RestoreFromAccountExport(ctx context.Context, reader io.Reader, coreAPI ipf
 func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err error) {
 	optsCleanup, err := opts.applyDefaults()
 	if err != nil {
-		return nil, errcode.TODO.Wrap(fmt.Errorf("error while applying default of messenger opts: %w", err))
+		return nil, errcode.ErrCode_TODO.Wrap(fmt.Errorf("error while applying default of messenger opts: %w", err))
 	}
 
 	tyberCtx, _, tyberEndSection := tyber.Section(context.Background(), opts.Logger, "Initializing MessengerService version "+bertyversion.Version)
@@ -183,11 +191,11 @@ func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err
 			return replayLogsToDB(ctx, client, db, opts.Logger)
 		}); err != nil {
 			cancel()
-			return nil, errcode.ErrDBWrite.Wrap(fmt.Errorf("unable to restore exported state: %w", err))
+			return nil, errcode.ErrCode_ErrDBWrite.Wrap(fmt.Errorf("unable to restore exported state: %w", err))
 		}
 	} else if err := db.InitDB(getEventsReplayerForDB(ctx, client, opts.Logger)); err != nil {
 		cancel()
-		return nil, errcode.TODO.Wrap(fmt.Errorf("error during db init: %w", err))
+		return nil, errcode.ErrCode_TODO.Wrap(fmt.Errorf("error during db init: %w", err))
 	}
 
 	tyber.LogStep(tyberCtx, opts.Logger, "Database initialization succeeded")
@@ -199,11 +207,11 @@ func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err
 	icr, err := client.ServiceGetConfiguration(ctx, &protocoltypes.ServiceGetConfiguration_Request{})
 	cancel()
 	if err != nil {
-		return nil, errcode.TODO.Wrap(fmt.Errorf("error while getting instance configuration: %w", err))
+		return nil, errcode.ErrCode_TODO.Wrap(fmt.Errorf("error while getting instance configuration: %w", err))
 	}
 
 	tyber.LogStep(tyberCtx, opts.Logger, "Got instance configuration", tyber.WithJSONDetail("InstanceConfiguration", icr))
-	pkStr := messengerutil.B64EncodeBytes(icr.GetAccountGroupPK())
+	pkStr := messengerutil.B64EncodeBytes(icr.GetAccountGroupPk())
 
 	shortPkStr := pkStr
 	const shortLen = 6
@@ -233,34 +241,44 @@ func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err
 		knownPeers:            make(map[string] /* peer.ID */ protocoltypes.GroupDeviceStatus_Type),
 		subsMutex:             &sync.Mutex{},
 		groupsToSubTo:         make(map[string]struct{}),
-		accountGroup:          icr.GetAccountGroupPK(),
+		accountGroup:          icr.GetAccountGroupPk(),
 		grpcInsecure:          opts.GRPCInsecureMode,
+		pushClients:           make(map[string]*grpc.ClientConn),
 	}
 
 	svc.eventHandler = messengerpayloads.NewEventHandler(ctx, db, &MetaFetcherFromProtocolClient{client: client}, newPostActionsService(&svc), opts.Logger, svc.dispatcher, false)
-
-	// @FIXME(push): temporary use noop push receiver
-	// svc.pushReceiver = bertypush.NewNoopPushReceiver()
+	svc.pushHandler = (bertypush.PushHandler)(nil)
+	dbFetcher := dbfetcher.NewDBFetcher(pkStr, db)
+	if opts.PushKey != nil {
+		svc.pushHandler, err = bertypush.NewPushHandler(client, dbFetcher, opts.PushKey, &bertypush.PushHandlerOpts{
+			Logger: opts.Logger,
+		})
+		if err != nil {
+			cancel()
+			return nil, errcode.ErrCode_ErrInternal.Wrap(fmt.Errorf("unable to init push handler: %w", err))
+		}
+	}
+	svc.pushReceiver = bertypush.NewPushReceiver(svc.pushHandler, svc.eventHandler, dbFetcher, opts.Logger)
 
 	// get or create account in DB
 	{
 		acc, err := svc.db.GetAccount()
 		switch {
-		case errcode.Is(err, errcode.ErrNotFound): // account not found, create a new one
+		case errcode.Is(err, errcode.ErrCode_ErrNotFound): // account not found, create a new one
 			tyber.LogStep(tyberCtx, opts.Logger, "Account not found, creating a new one", tyber.WithDetail("PublicKey", pkStr))
 			ret, err := svc.internalInstanceShareableBertyID(ctx, &mt.InstanceShareableBertyID_Request{})
 			if err != nil {
-				return nil, errcode.TODO.Wrap(fmt.Errorf("error while creating shareable account link: %w", err))
+				return nil, errcode.ErrCode_TODO.Wrap(fmt.Errorf("error while creating shareable account link: %w", err))
 			}
 
-			if err = svc.db.FirstOrCreateAccount(pkStr, ret.GetWebURL()); err != nil {
+			if err = svc.db.FirstOrCreateAccount(pkStr, ret.GetWebUrl()); err != nil {
 				return nil, err
 			}
 		case err != nil: // internal error
-			return nil, errcode.ErrInternal.Wrap(err)
+			return nil, errcode.ErrCode_ErrInternal.Wrap(err)
 		case pkStr != acc.GetPublicKey(): // Check that we are connected to the correct node
 			// FIXME: use errcode
-			return nil, errcode.TODO.Wrap(errors.New("messenger's account key does not match protocol's account key"))
+			return nil, errcode.ErrCode_TODO.Wrap(errors.New("messenger's account key does not match protocol's account key"))
 		default: // account exists, and public keys match
 			// noop
 			tyber.LogStep(tyberCtx, opts.Logger, "Found account", tyber.WithDetail("PublicKey", pkStr))
@@ -299,23 +317,20 @@ func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err
 	}})
 
 	if opts.PlatformPushToken != nil {
-		icr, err = client.ServiceGetConfiguration(ctx, &protocoltypes.ServiceGetConfiguration_Request{})
-		if err != nil {
-			return nil, err
+		token, err := db.GetPushDeviceToken(pkStr)
+		if err != nil && !errcode.Is(err, errcode.ErrCode_ErrNotFound) {
+			return nil, errcode.ErrCode_ErrInternal.Wrap(err)
+		} else if errcode.Is(err, errcode.ErrCode_ErrNotFound) || (token.TokenType == opts.PlatformPushToken.TokenType && !bytes.Equal(token.Token, opts.PlatformPushToken.Token)) {
+			if _, err := svc.PushSetDeviceToken(ctx, &mt.PushSetDeviceToken_Request{
+				Receiver: opts.PlatformPushToken,
+			}); err != nil {
+				return nil, errcode.ErrCode_ErrInternal.Wrap(err)
+			}
 		}
-
-		// FIXME(push): PushSetDeviceToken not available anymore
-		// if icr.DevicePushToken == nil || (icr.DevicePushToken.TokenType == opts.PlatformPushToken.TokenType && !bytes.Equal(icr.DevicePushToken.Token, opts.PlatformPushToken.Token)) {
-		// if _, err := client.PushSetDeviceToken(ctx, &protocoltypes.PushSetDeviceToken_Request{
-		// 	Receiver: opts.PlatformPushToken,
-		// }); err != nil {
-		// 	return nil, errcode.ErrInternal.Wrap(err)
-		// }
-		// }
 	}
 
 	// Subscribe to account group metadata
-	svc.accountGroup = icr.GetAccountGroupPK()
+	svc.accountGroup = icr.GetAccountGroupPk()
 
 	// subscribe to groups
 	{
@@ -327,12 +342,12 @@ func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err
 		for _, cv := range convs {
 			gpkb, err := messengerutil.B64DecodeBytes(cv.GetPublicKey())
 			if err != nil {
-				return nil, errcode.ErrDeserialization.Wrap(err)
+				return nil, errcode.ErrCode_ErrDeserialization.Wrap(err)
 			}
 
-			_, err = svc.protocolClient.ActivateGroup(ctx, &protocoltypes.ActivateGroup_Request{GroupPK: gpkb})
+			_, err = svc.protocolClient.ActivateGroup(ctx, &protocoltypes.ActivateGroup_Request{GroupPk: gpkb})
 			if err != nil {
-				return nil, errcode.TODO.Wrap(err)
+				return nil, errcode.ErrCode_TODO.Wrap(err)
 			}
 
 			svc.groupsToSubTo[cv.GetPublicKey()] = struct{}{}
@@ -343,17 +358,17 @@ func New(client protocoltypes.ProtocolServiceClient, opts *Opts) (_ Service, err
 	{
 		contacts, err := svc.db.GetContactsByState(mt.Contact_OutgoingRequestSent)
 		if err != nil {
-			return nil, errcode.ErrDBRead.Wrap(fmt.Errorf("error while fetching contacts from db: %w", err))
+			return nil, errcode.ErrCode_ErrDBRead.Wrap(fmt.Errorf("error while fetching contacts from db: %w", err))
 		}
 		for _, c := range contacts {
 			gpkb, err := messengerutil.B64DecodeBytes(c.GetConversationPublicKey())
 			if err != nil {
-				return nil, errcode.ErrDeserialization.Wrap(err)
+				return nil, errcode.ErrCode_ErrDeserialization.Wrap(err)
 			}
 
-			_, err = svc.protocolClient.ActivateGroup(ctx, &protocoltypes.ActivateGroup_Request{GroupPK: gpkb})
+			_, err = svc.protocolClient.ActivateGroup(ctx, &protocoltypes.ActivateGroup_Request{GroupPk: gpkb})
 			if err != nil {
-				return nil, errcode.TODO.Wrap(err)
+				return nil, errcode.ErrCode_TODO.Wrap(err)
 			}
 
 			svc.groupsToSubTo[c.GetConversationPublicKey()] = struct{}{}
@@ -375,12 +390,12 @@ func (svc *service) sendAccountUserInfo(ctx context.Context, groupPK string) (er
 
 	pk, err := messengerutil.B64DecodeBytes(groupPK)
 	if err != nil {
-		return errcode.ErrDeserialization.Wrap(err)
+		return errcode.ErrCode_ErrDeserialization.Wrap(err)
 	}
 
 	acc, err := svc.db.GetAccount()
 	if err != nil {
-		return errcode.ErrDBRead.Wrap(err)
+		return errcode.ErrCode_ErrDBRead.Wrap(err)
 	}
 
 	am, err := mt.AppMessage_TypeSetUserInfo.MarshalPayload(
@@ -389,15 +404,15 @@ func (svc *service) sendAccountUserInfo(ctx context.Context, groupPK string) (er
 		&mt.AppMessage_SetUserInfo{DisplayName: acc.GetDisplayName()},
 	)
 	if err != nil {
-		return errcode.ErrSerialization.Wrap(err)
+		return errcode.ErrCode_ErrSerialization.Wrap(err)
 	}
 
-	sendReply, err := svc.protocolClient.AppMetadataSend(ctx, &protocoltypes.AppMetadataSend_Request{GroupPK: pk, Payload: am})
+	sendReply, err := svc.protocolClient.AppMetadataSend(ctx, &protocoltypes.AppMetadataSend_Request{GroupPk: pk, Payload: am})
 	if err != nil {
-		return errcode.ErrProtocolSend.Wrap(err)
+		return errcode.ErrCode_ErrProtocolSend.Wrap(err)
 	}
 
-	endSection(nil, "Sent account info", tyber.WithCIDDetail("CID", sendReply.CID))
+	endSection(nil, "Sent account info", tyber.WithCIDDetail("CID", sendReply.Cid))
 	return nil
 }
 
@@ -414,6 +429,11 @@ func (svc *service) ActivateGroup(groupPK []byte) error {
 	svc.subsMutex.Lock()
 	defer svc.subsMutex.Unlock()
 
+	if _, ok := svc.groupsToSubTo[messengerutil.B64EncodeBytes(groupPK)]; ok {
+		svc.logger.Warn("Already subscribed to group. Don't call subscribeToGroup again.", zap.String("gpk", messengerutil.B64EncodeBytes(groupPK)))
+		return nil
+	}
+
 	// mark group
 	svc.groupsToSubTo[messengerutil.B64EncodeBytes(groupPK)] = struct{}{}
 
@@ -457,135 +477,13 @@ func (svc *service) SendAck(cid, conversationPK string) error {
 	}
 
 	reply, err := svc.protocolClient.AppMessageSend(svc.ctx, &protocoltypes.AppMessageSend_Request{
-		GroupPK: cpk,
+		GroupPk: cpk,
 		Payload: amp,
 	})
 	if err != nil {
 		return logError("Protocol error", err)
 	}
-	tyber.LogStep(svc.ctx, svc.logger, "Acknowledge sent", tyber.WithCIDDetail("CID", reply.GetCID()))
-
-	return nil
-}
-
-func (svc *service) sharePushTokenForConversation(conversation *mt.Conversation) error {
-	if conversation == nil {
-		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("no conversation supplied"))
-	}
-
-	svc.logger.Info("sharing push token", logutil.PrivateString("conversation-pk", conversation.PublicKey))
-
-	account, err := svc.db.GetAccount()
-	if err != nil {
-		return errcode.ErrDBRead.Wrap(err)
-	}
-
-	if account.DevicePushToken == nil {
-		svc.logger.Warn("no push token known, won't share it")
-		return weshnet_errcode.ErrPushUnknownDestination.Wrap(fmt.Errorf("no push token known, won't share it"))
-	}
-
-	if account.DevicePushServer == nil {
-		svc.logger.Warn("no push server known, won't share push token")
-		return weshnet_errcode.ErrPushUnknownProvider.Wrap(fmt.Errorf("no push server known, won't share push token"))
-	}
-
-	pushServer := &protocoltypes.PushServer{}
-	if err := pushServer.Unmarshal(account.DevicePushServer); err != nil {
-		return errcode.ErrDeserialization.Wrap(fmt.Errorf("unable to unmarshal push server: %w", err))
-	}
-
-	pushToken := &protocoltypes.PushServiceReceiver{}
-	if err := pushToken.Unmarshal(account.DevicePushToken); err != nil {
-		return errcode.ErrDeserialization.Wrap(fmt.Errorf("unable to unmarshal device push token: %w", err))
-	}
-
-	if err := svc.sharePushTokenForConversationInternal(conversation, pushServer, pushToken); err != nil {
-		return errcode.ErrInternal.Wrap(fmt.Errorf("unable to share device push token: %w", err))
-	}
-
-	return nil
-}
-
-func (svc *service) sharePushTokenForConversationInternal(conversation *mt.Conversation, pushServer *protocoltypes.PushServer, pushToken *protocoltypes.PushServiceReceiver) error {
-	if len(pushToken.Token) == 0 {
-		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing token in PushServiceReceiver"))
-	}
-	if pushToken.TokenType == 0 {
-		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("wrong token type in PushServiceReceiver"))
-	}
-	if len(pushToken.RecipientPublicKey) == 0 {
-		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing recipient public key in PushServiceReceiver"))
-	}
-	if len(pushToken.BundleID) == 0 {
-		return errcode.ErrInvalidInput.Wrap(fmt.Errorf("missing bundleID in PushServiceReceiver"))
-	}
-
-	tokenIdentifier := makeSharedPushIdentifier(pushServer, pushToken)
-
-	// pubKey, err := messengerutil.B64DecodeBytes(conversation.PublicKey)
-	// if err != nil {
-	// 	return errcode.ErrSerialization.Wrap(err)
-	// }
-
-	if conversation.SharedPushTokenIdentifier != tokenIdentifier {
-		// FIXME(push): push share token not available anymore
-		// if _, err := svc.protocolClient.PushShareToken(svc.ctx, &protocoltypes.PushShareToken_Request{
-		// 	GroupPK:  pubKey,
-		// 	Server:   pushServer,
-		// 	Receiver: pushToken,
-		// }); err != nil {
-		// 	return err
-		// }
-
-		if _, err := svc.db.UpdateConversation(mt.Conversation{PublicKey: conversation.PublicKey, SharedPushTokenIdentifier: tokenIdentifier}); err != nil {
-			return errcode.ErrDBWrite.Wrap(err)
-		}
-
-		conv, err := svc.db.GetConversationByPK(conversation.PublicKey)
-		if err != nil {
-			return errcode.ErrDBRead.Wrap(err)
-		}
-
-		if err := svc.dispatcher.StreamEvent(mt.StreamEvent_TypeConversationUpdated, &mt.StreamEvent_ConversationUpdated{Conversation: conv}, false); err != nil {
-			return errcode.TODO.Wrap(err)
-		}
-	}
-
-	return nil
-}
-
-func makeSharedPushIdentifier(server *protocoltypes.PushServer, token *protocoltypes.PushServiceReceiver) string {
-	// @TODO(@gfanton): make something smarter here
-	b64serverKey := base64.StdEncoding.EncodeToString(server.ServerKey)
-	b64token := base64.StdEncoding.EncodeToString(token.Token)
-
-	return fmt.Sprintf("%s-%s", b64serverKey, b64token)
-}
-
-func (svc *service) pushDeviceTokenBroadcast(account *mt.Account) error {
-	conversations, err := svc.db.GetAllConversations()
-	if err != nil {
-		return errcode.ErrDBRead.Wrap(err)
-	}
-
-	svc.logger.Info("sharing push token", zap.Int("conversation-count", len(conversations)))
-
-	server := &protocoltypes.PushServer{}
-	if err := server.Unmarshal(account.DevicePushServer); err != nil {
-		return errcode.ErrDeserialization.Wrap(err)
-	}
-
-	token := &protocoltypes.PushServiceReceiver{}
-	if err := token.Unmarshal(account.DevicePushToken); err != nil {
-		return errcode.ErrDeserialization.Wrap(err)
-	}
-
-	for _, c := range conversations {
-		if err := svc.sharePushTokenForConversationInternal(c, server, token); err != nil {
-			svc.logger.Error("unable to share push token on conversation", logutil.PrivateString("conversation-pk", c.PublicKey), zap.Error(err))
-		}
-	}
+	tyber.LogStep(svc.ctx, svc.logger, "Acknowledge sent", tyber.WithCIDDetail("CID", reply.GetCid()))
 
 	return nil
 }
@@ -595,18 +493,18 @@ type MetaFetcherFromProtocolClient struct {
 }
 
 func (svc *MetaFetcherFromProtocolClient) OwnMemberAndDevicePKForConversation(ctx context.Context, conversationPK []byte) (member []byte, device []byte, err error) {
-	gi, err := svc.client.GroupInfo(ctx, &protocoltypes.GroupInfo_Request{GroupPK: conversationPK})
+	gi, err := svc.client.GroupInfo(ctx, &protocoltypes.GroupInfo_Request{GroupPk: conversationPK})
 	if err != nil {
 		return nil, nil, err
 	}
 
-	return gi.MemberPK, gi.DevicePK, nil
+	return gi.MemberPk, gi.DevicePk, nil
 }
 
 func (svc *MetaFetcherFromProtocolClient) GroupPKForContact(ctx context.Context, contactPK []byte) ([]byte, error) {
-	groupInfoReply, err := svc.client.GroupInfo(ctx, &protocoltypes.GroupInfo_Request{ContactPK: contactPK})
+	groupInfoReply, err := svc.client.GroupInfo(ctx, &protocoltypes.GroupInfo_Request{ContactPk: contactPK})
 	if err != nil {
-		return nil, errcode.ErrProtocolGetGroupInfo.Wrap(err)
+		return nil, errcode.ErrCode_ErrProtocolGetGroupInfo.Wrap(err)
 	}
 
 	return groupInfoReply.GetGroup().GetPublicKey(), nil
