@@ -8,7 +8,6 @@ import (
 	"encoding/base64"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"net"
 	"net/http"
 	"os"
@@ -17,15 +16,15 @@ import (
 	"testing"
 	"time"
 
-	sqlite "github.com/flyingtime/gorm-sqlcipher"
-	"github.com/gogo/protobuf/proto"
 	"github.com/oklog/run"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"go.uber.org/zap"
 	"golang.org/x/crypto/nacl/box"
+	"google.golang.org/protobuf/proto"
 	"gorm.io/gorm"
 
+	sqlite "berty.tech/berty/v2/go/internal/gorm-sqlcipher"
 	"berty.tech/berty/v2/go/internal/grpcserver"
 	"berty.tech/berty/v2/go/internal/messengerdb"
 	"berty.tech/berty/v2/go/internal/messengerutil"
@@ -33,9 +32,9 @@ import (
 	"berty.tech/berty/v2/go/pkg/bertyvcissuer"
 	"berty.tech/berty/v2/go/pkg/directorytypes"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
-	"berty.tech/weshnet/pkg/protocoltypes"
-	"berty.tech/weshnet/pkg/testutil"
-	"berty.tech/weshnet/pkg/verifiablecredstypes"
+	"berty.tech/weshnet/v2/pkg/protocoltypes"
+	"berty.tech/weshnet/v2/pkg/testutil"
+	"berty.tech/weshnet/v2/pkg/verifiablecredstypes"
 )
 
 func TestServiceStream(t *testing.T) {
@@ -152,7 +151,7 @@ func TestServiceContactRequest(t *testing.T) {
 		require.NoError(t, err)
 		require.NoError(t, deeplinkReply.Link.IsValid())
 		req := &messengertypes.SendContactRequest_Request{
-			BertyID:     deeplinkReply.Link.BertyID,
+			BertyId:     deeplinkReply.Link.BertyId,
 			Metadata:    metadata,
 			OwnMetadata: ownMetadata,
 		}
@@ -163,7 +162,7 @@ func TestServiceContactRequest(t *testing.T) {
 		assert.Len(t, node.GetAllConversations(), 1)
 	}
 
-	contactPK := base64.RawURLEncoding.EncodeToString(deeplinkReply.GetLink().GetBertyID().GetAccountPK())
+	contactPK := base64.RawURLEncoding.EncodeToString(deeplinkReply.GetLink().GetBertyId().GetAccountPk())
 	require.NotEmpty(t, contactPK)
 
 	// check for contact
@@ -253,8 +252,8 @@ func TestBroken1To1AddContact(t *testing.T) {
 
 	// Init accounts
 	var (
-		alice = NewTestingAccount(ctx, t, clients[0], nil, logger)
-		bob   = NewTestingAccount(ctx, t, clients[1], nil, logger)
+		alice = NewTestingAccount(ctx, t, clients[0].Client, nil, logger)
+		bob   = NewTestingAccount(ctx, t, clients[1].Client, nil, logger)
 	)
 	{
 		defer alice.Close()
@@ -300,8 +299,8 @@ func TestBroken1To1Exchange(t *testing.T) {
 
 	// Init accounts
 	var (
-		alice = NewTestingAccount(ctx, t, clients[0], nil, logger)
-		bob   = NewTestingAccount(ctx, t, clients[1], nil, logger)
+		alice = NewTestingAccount(ctx, t, clients[0].Client, nil, logger)
+		bob   = NewTestingAccount(ctx, t, clients[1].Client, nil, logger)
 	)
 	{
 		defer alice.Close()
@@ -356,14 +355,14 @@ func TestBrokenPeersCreateJoinConversation(t *testing.T) {
 	// create nodes
 	var creator *TestingAccount
 	{
-		creator = NewTestingAccount(ctx, t, clients[0], nil, logger)
+		creator = NewTestingAccount(ctx, t, clients[0].Client, nil, logger)
 		defer creator.Close()
 		creator.SetName(t, "Creator")
 	}
 	joiners := make([]*TestingAccount, accountsAmount-1)
 	{
 		for i := 0; i < accountsAmount-1; i++ {
-			joiners[i] = NewTestingAccount(ctx, t, clients[i+1], nil, logger)
+			joiners[i] = NewTestingAccount(ctx, t, clients[i+1].Client, nil, logger)
 			defer joiners[i].Close()
 			joiners[i].SetName(t, "Joiner #"+strconv.Itoa(i))
 		}
@@ -378,12 +377,12 @@ func TestBrokenPeersCreateJoinConversation(t *testing.T) {
 	gpk := createdConv.GetPublicKey()
 	gpkb, err := messengerutil.B64DecodeBytes(gpk)
 	require.NoError(t, err)
-	sbg, err := creator.GetClient().ShareableBertyGroup(ctx, &messengertypes.ShareableBertyGroup_Request{GroupPK: gpkb, GroupName: convName})
+	sbg, err := creator.GetClient().ShareableBertyGroup(ctx, &messengertypes.ShareableBertyGroup_Request{GroupPk: gpkb, GroupName: convName})
 	require.NoError(t, err)
 
 	// joiners join the conversation
 	for _, joiner := range joiners {
-		ret, err := joiner.GetClient().ConversationJoin(ctx, &messengertypes.ConversationJoin_Request{Link: sbg.GetWebURL()})
+		ret, err := joiner.GetClient().ConversationJoin(ctx, &messengertypes.ConversationJoin_Request{Link: sbg.GetWebUrl()})
 		require.NoError(t, err)
 		require.Empty(t, ret)
 	}
@@ -428,7 +427,7 @@ func TestBrokenPeersCreateJoinConversation(t *testing.T) {
 	}
 
 	subCtx, subCancel := context.WithTimeout(ctx, time.Second*45)
-	cl, err := clients[1].EventStream(subCtx, &messengertypes.EventStream_Request{
+	cl, err := clients[1].Client.EventStream(subCtx, &messengertypes.EventStream_Request{
 		ShallowAmount: 1,
 	})
 	require.NoError(t, err)
@@ -458,7 +457,7 @@ func TestBrokenPeersCreateJoinConversation(t *testing.T) {
 		})
 		require.NoError(t, err)
 
-		_, err = clients[0].Interact(
+		_, err = clients[0].Client.Interact(
 			ctx,
 			&messengertypes.Interact_Request{
 				Type:                  messengertypes.AppMessage_TypeUserMessage,
@@ -532,7 +531,7 @@ func TestBroken3PeersExchange(t *testing.T) {
 	// create nodes
 	var creator *TestingAccount
 	{
-		creator = NewTestingAccount(ctx, t, clients[0], nil, logger)
+		creator = NewTestingAccount(ctx, t, clients[0].Client, nil, logger)
 		defer creator.Close()
 		creator.DrainInitEvents(t)
 		creator.SetNameAndDrainUpdate(t, "Creator")
@@ -540,7 +539,7 @@ func TestBroken3PeersExchange(t *testing.T) {
 	joiners := make([]*TestingAccount, 2)
 	{
 		for i := 0; i < 2; i++ {
-			joiners[i] = NewTestingAccount(ctx, t, clients[i+1], nil, logger)
+			joiners[i] = NewTestingAccount(ctx, t, clients[i+1].Client, nil, logger)
 			defer joiners[i].Close()
 			joiners[i].DrainInitEvents(t)
 			joiners[i].SetNameAndDrainUpdate(t, "Joiner #"+strconv.Itoa(i))
@@ -591,17 +590,17 @@ func TestBrokenConversationInvitation(t *testing.T) {
 	// create nodes
 	var alice, bob, john *TestingAccount
 	{
-		alice = NewTestingAccount(ctx, t, clients[0], nil, logger)
+		alice = NewTestingAccount(ctx, t, clients[0].Client, nil, logger)
 		defer alice.Close()
 		alice.SetName(t, "Alice")
 		alice.DrainInitEvents(t)
 
-		bob = NewTestingAccount(ctx, t, clients[1], nil, logger)
+		bob = NewTestingAccount(ctx, t, clients[1].Client, nil, logger)
 		defer bob.Close()
 		bob.SetName(t, "Bob")
 		bob.DrainInitEvents(t)
 
-		john = NewTestingAccount(ctx, t, clients[2], nil, logger)
+		john = NewTestingAccount(ctx, t, clients[2].Client, nil, logger)
 		defer john.Close()
 		john.SetName(t, "John")
 		john.DrainInitEvents(t)
@@ -657,17 +656,17 @@ func TestBrokenConversationInvitationAndExchange(t *testing.T) {
 	// create nodes
 	var alice, bob, john *TestingAccount
 	{
-		alice = NewTestingAccount(ctx, t, clients[0], nil, logger)
+		alice = NewTestingAccount(ctx, t, clients[0].Client, nil, logger)
 		defer alice.Close()
 		alice.SetName(t, "Alice")
 		alice.DrainInitEvents(t)
 
-		bob = NewTestingAccount(ctx, t, clients[1], nil, logger)
+		bob = NewTestingAccount(ctx, t, clients[1].Client, nil, logger)
 		defer bob.Close()
 		bob.SetName(t, "Bob")
 		bob.DrainInitEvents(t)
 
-		john = NewTestingAccount(ctx, t, clients[2], nil, logger)
+		john = NewTestingAccount(ctx, t, clients[2].Client, nil, logger)
 		defer john.Close()
 		john.SetName(t, "John")
 		john.DrainInitEvents(t)
@@ -730,8 +729,8 @@ func TestBrokenConversationOpenClose(t *testing.T) {
 
 	// Init accounts
 	var (
-		alice = NewTestingAccount(ctx, t, clients[0], nil, logger)
-		bob   = NewTestingAccount(ctx, t, clients[1], nil, logger)
+		alice = NewTestingAccount(ctx, t, clients[0].Client, nil, logger)
+		bob   = NewTestingAccount(ctx, t, clients[1].Client, nil, logger)
 	)
 	{
 		defer alice.Close()
@@ -754,7 +753,7 @@ func TestBrokenConversationOpenClose(t *testing.T) {
 
 	// Bob opens the conversation
 	{
-		_, err := bob.GetClient().ConversationOpen(ctx, &messengertypes.ConversationOpen_Request{GroupPK: groupPK})
+		_, err := bob.GetClient().ConversationOpen(ctx, &messengertypes.ConversationOpen_Request{GroupPk: groupPK})
 		require.NoError(t, err)
 	}
 
@@ -797,7 +796,7 @@ func TestBrokenConversationOpenClose(t *testing.T) {
 
 	// Bob closes the conversation
 	{
-		_, err := bob.GetClient().ConversationClose(ctx, &messengertypes.ConversationClose_Request{GroupPK: groupPK})
+		_, err := bob.GetClient().ConversationClose(ctx, &messengertypes.ConversationClose_Request{GroupPk: groupPK})
 		require.NoError(t, err)
 	}
 
@@ -840,7 +839,7 @@ func TestBrokenConversationOpenClose(t *testing.T) {
 
 	// Alice opens the conversation
 	{
-		_, err := alice.GetClient().ConversationOpen(ctx, &messengertypes.ConversationOpen_Request{GroupPK: groupPK})
+		_, err := alice.GetClient().ConversationOpen(ctx, &messengertypes.ConversationOpen_Request{GroupPk: groupPK})
 		require.NoError(t, err)
 	}
 
@@ -1114,12 +1113,12 @@ func testSendGroupMessage(ctx context.Context, t *testing.T, groupPK string, sen
 		eventPayload, err := event.UnmarshalPayload()
 		require.NoError(t, err)
 		interaction := eventPayload.(*messengertypes.StreamEvent_InteractionUpdated).Interaction
-		require.NotEmpty(t, interaction.GetCID())
-		messageCid = interaction.GetCID()
+		require.NotEmpty(t, interaction.GetCid())
+		messageCid = interaction.GetCid()
 		require.Equal(t, interaction.GetType(), messengertypes.AppMessage_TypeUserMessage)
 		require.Equal(t, interaction.GetConversationPublicKey(), groupPK)
 		require.True(t, interaction.GetIsMine())
-		require.Equal(t, interaction.GetCID(), messageCid)
+		require.Equal(t, interaction.GetCid(), messageCid)
 		interactionPayload, err := interaction.UnmarshalPayload()
 		require.NoError(t, err)
 		userMessage := interactionPayload.(*messengertypes.AppMessage_UserMessage)
@@ -1179,7 +1178,7 @@ func testSendGroupMessage(ctx context.Context, t *testing.T, groupPK string, sen
 				eventPayload, err := event.UnmarshalPayload()
 				require.NoError(t, err)
 				interaction := eventPayload.(*messengertypes.StreamEvent_InteractionUpdated).Interaction
-				require.NotEmpty(t, interaction.GetCID())
+				require.NotEmpty(t, interaction.GetCid())
 				require.Equal(t, interaction.GetConversationPublicKey(), groupPK)
 				interactionPayload, err := interaction.UnmarshalPayload()
 				require.NoError(t, err)
@@ -1187,14 +1186,14 @@ func testSendGroupMessage(ctx context.Context, t *testing.T, groupPK string, sen
 				case interaction.GetType() == messengertypes.AppMessage_TypeAcknowledge && interaction.GetIsMine():
 					require.False(t, gotOwnAck)
 					gotOwnAck = true
-					require.Equal(t, interaction.GetTargetCID(), messageCid)
+					require.Equal(t, interaction.GetTargetCid(), messageCid)
 				case interaction.GetType() == messengertypes.AppMessage_TypeAcknowledge && !interaction.GetIsMine():
-					require.Equal(t, interaction.GetTargetCID(), messageCid)
+					require.Equal(t, interaction.GetTargetCid(), messageCid)
 					gotOthersAcks++
 				case interaction.GetType() == messengertypes.AppMessage_TypeUserMessage:
 					require.False(t, gotMsg)
 					gotMsg = true
-					require.Equal(t, interaction.GetCID(), messageCid)
+					require.Equal(t, interaction.GetCid(), messageCid)
 					userMessage := interactionPayload.(*messengertypes.AppMessage_UserMessage)
 					require.Equal(t, userMessage.GetBody(), msg)
 					require.LessOrEqual(t, beforeSend, interaction.GetSentDate())
@@ -1217,11 +1216,11 @@ func testSendGroupMessage(ctx context.Context, t *testing.T, groupPK string, sen
 		eventPayload, err := event.UnmarshalPayload()
 		require.NoError(t, err)
 		interaction := eventPayload.(*messengertypes.StreamEvent_InteractionUpdated).Interaction
-		require.NotEmpty(t, interaction.GetCID())
+		require.NotEmpty(t, interaction.GetCid())
 		require.Equal(t, interaction.GetType(), messengertypes.AppMessage_TypeAcknowledge)
 		require.Equal(t, interaction.GetConversationPublicKey(), groupPK)
 		require.False(t, interaction.GetIsMine())
-		require.Equal(t, interaction.GetTargetCID(), messageCid)
+		require.Equal(t, interaction.GetTargetCid(), messageCid)
 		logger.Debug("testSendGroupMessage: message ack received by creator")
 		// FIXME: check if the ack is from the good receiver, or useless?
 	}
@@ -1269,7 +1268,7 @@ func testCreateConversation(ctx context.Context, t *testing.T, creator *TestingA
 			require.NoError(t, err)
 			interaction := eventPayload.(*messengertypes.StreamEvent_InteractionUpdated).GetInteraction()
 			require.Equal(t, interaction.GetType(), messengertypes.AppMessage_TypeGroupInvitation)
-			require.NotEmpty(t, interaction.GetCID())
+			require.NotEmpty(t, interaction.GetCid())
 			require.NotEqual(t, convPK, interaction.GetConversationPublicKey())
 			require.True(t, interaction.GetIsMine())
 			// FIXME: require.Equal, 1to1conv.pk
@@ -1303,7 +1302,7 @@ func testCreateConversation(ctx context.Context, t *testing.T, creator *TestingA
 			require.NoError(t, err)
 			interaction := eventPayload.(*messengertypes.StreamEvent_InteractionUpdated).GetInteraction()
 			require.Equal(t, interaction.GetType(), messengertypes.AppMessage_TypeGroupInvitation)
-			require.NotEmpty(t, interaction.GetCID())
+			require.NotEmpty(t, interaction.GetCid())
 			require.NotEqual(t, convPK, interaction.GetConversationPublicKey())
 			require.False(t, interaction.GetIsMine())
 			// FIXME: require.Equal, 1to1conv.pk
@@ -1363,7 +1362,7 @@ func TestAccountUpdate(t *testing.T) {
 
 	nodes := make([]*TestingAccount, l)
 	for i := range nodes {
-		nodes[i] = NewTestingAccount(ctx, t, clients[i], protocols[i].Client, logger)
+		nodes[i] = NewTestingAccount(ctx, t, clients[i].Client, protocols[i].Client, logger)
 		nodes[i].SetName(t, fmt.Sprintf("node-%d", i))
 		close := nodes[i].ProcessWholeStream(t)
 		defer close()
@@ -1425,7 +1424,7 @@ func TestFlappyAccountUpdateGroup(t *testing.T) {
 
 	nodes := make([]*TestingAccount, l)
 	for i := range nodes {
-		nodes[i] = NewTestingAccount(ctx, t, clients[i], protocols[i].Client, logger)
+		nodes[i] = NewTestingAccount(ctx, t, clients[i].Client, protocols[i].Client, logger)
 		nodes[i].SetName(t, fmt.Sprintf("node-%d", i))
 		close := nodes[i].ProcessWholeStream(t)
 		defer close()
@@ -1566,7 +1565,7 @@ func Test_exportMessengerData(t *testing.T) {
 	gormDB.Create(&messengertypes.Conversation{PublicKey: "pk_conv_2", UnreadCount: 2000, IsOpen: true})
 	gormDB.Create(&messengertypes.Conversation{PublicKey: "pk_conv_3", UnreadCount: 3000, IsOpen: false})
 
-	tmpFile, err := ioutil.TempFile(os.TempDir(), "messenger-export-")
+	tmpFile, err := os.CreateTemp(os.TempDir(), "messenger-export-")
 	require.NoError(t, err)
 
 	err = exportMessengerData(tmpFile, db)
@@ -1619,7 +1618,7 @@ func TestReply(t *testing.T) {
 		ConversationPublicKey: convPK,
 	})
 	require.NoError(t, err)
-	require.NotEmpty(t, interactReply.GetCID())
+	require.NotEmpty(t, interactReply.GetCid())
 	time.Sleep(1 * time.Second)
 
 	// reply
@@ -1629,17 +1628,17 @@ func TestReply(t *testing.T) {
 		Type:                  messengertypes.AppMessage_TypeUserMessage,
 		Payload:               payload,
 		ConversationPublicKey: convPK,
-		TargetCID:             interactReply.GetCID(),
+		TargetCid:             interactReply.GetCid(),
 	})
 	require.NoError(t, err)
-	require.NotEmpty(t, replyReply.GetCID())
+	require.NotEmpty(t, replyReply.GetCid())
 	time.Sleep(1 * time.Second)
 
 	// check reply interaction in nodes
 	for _, user := range nodes {
-		replyInteraction := user.GetInteraction(t, replyReply.GetCID())
+		replyInteraction := user.GetInteraction(t, replyReply.GetCid())
 		require.NotNil(t, replyInteraction)
-		require.Equal(t, interactReply.CID, replyInteraction.TargetCID)
+		require.Equal(t, interactReply.Cid, replyInteraction.TargetCid)
 
 		replyPayload, err := replyInteraction.UnmarshalPayload()
 		require.NoError(t, err)
@@ -1676,14 +1675,14 @@ func TestAck(t *testing.T) {
 		ConversationPublicKey: convPK,
 	})
 	require.NoError(t, err)
-	require.NotEmpty(t, interactRes.GetCID())
+	require.NotEmpty(t, interactRes.GetCid())
 	time.Sleep(2 * time.Second)
 
 	// check reply interaction in nodes
 	for _, user := range nodes {
-		retrievedInteraction := user.GetInteraction(t, interactRes.GetCID())
+		retrievedInteraction := user.GetInteraction(t, interactRes.GetCid())
 		require.NotNil(t, retrievedInteraction)
-		require.Equal(t, retrievedInteraction.CID, interactRes.CID)
+		require.Equal(t, retrievedInteraction.Cid, interactRes.Cid)
 		require.Equal(t, retrievedInteraction.Acknowledged, true)
 	}
 }
@@ -1705,7 +1704,7 @@ func TestDirectoryService(t *testing.T) {
 
 	nodes := make([]*TestingAccount, l)
 	for i := range nodes {
-		nodes[i] = NewTestingAccount(ctx, t, clients[i], protocols[i].Client, logger)
+		nodes[i] = NewTestingAccount(ctx, t, clients[i].Client, protocols[i].Client, logger)
 		nodes[i].SetName(t, fmt.Sprintf("node-%d", i))
 		closeFn := nodes[i].ProcessWholeStream(t)
 		defer closeFn()
@@ -1788,15 +1787,15 @@ func testHelperRegisterNewNumberOnDirectoryService(ctx context.Context, t *testi
 	require.NotEmpty(t, pk0)
 
 	initResponse, err := node.protocolClient.CredentialVerificationServiceInitFlow(ctx, &protocoltypes.CredentialVerificationServiceInitFlow_Request{
-		ServiceURL: vcIssuer.GetServerRootURL(),
+		ServiceUrl: vcIssuer.GetServerRootURL(),
 		PublicKey:  pk0,
 		Link:       account0.Account.Link,
 	})
 	require.NoError(t, err)
-	callbackURI := vcIssuer.TestHelperIssueTokenCallbackURI(t, initResponse.URL, identifier)
+	callbackURI := vcIssuer.TestHelperIssueTokenCallbackURI(t, initResponse.Url, identifier)
 
 	_, err = node.protocolClient.CredentialVerificationServiceCompleteFlow(ctx, &protocoltypes.CredentialVerificationServiceCompleteFlow_Request{
-		CallbackURI: callbackURI,
+		CallbackUri: callbackURI,
 	})
 	require.NoError(t, err)
 
@@ -1808,6 +1807,7 @@ func testHelperRegisterNewNumberOnDirectoryService(ctx context.Context, t *testi
 		ServerAddr:  directoryHost,
 		Identifier:  identifier,
 	})
+	require.NoError(t, err)
 
 	// FIXME: Remove sleep, make sure DirectoryServiceRegister DB event has been dispatched locally
 	time.Sleep(time.Millisecond * 100)
@@ -1832,7 +1832,7 @@ func testHelperGetQueryResult(ctx context.Context, t *testing.T, client messenge
 
 		countResults++
 
-		require.Equal(t, expectedResults[result.DirectoryIdentifier], result.AccountURI)
+		require.Equal(t, expectedResults[result.DirectoryIdentifier], result.AccountUri)
 	}
 
 	require.Equal(t, len(expectedResults), countResults)
