@@ -8,11 +8,11 @@ import (
 	"path"
 	"time"
 
-	"github.com/gogo/protobuf/proto"
 	"go.uber.org/zap"
+	"google.golang.org/protobuf/proto"
 
 	"berty.tech/berty/v2/go/internal/accountutils"
-	"berty.tech/berty/v2/go/internal/logutil"
+	"berty.tech/berty/v2/go/internal/dbfetcher"
 	"berty.tech/berty/v2/go/internal/messengerdb"
 	"berty.tech/berty/v2/go/internal/messengerpayloads"
 	"berty.tech/berty/v2/go/pkg/accounttypes"
@@ -20,12 +20,14 @@ import (
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
 	"berty.tech/berty/v2/go/pkg/pushtypes"
+	"berty.tech/weshnet/v2"
+	"berty.tech/weshnet/v2/pkg/logutil"
 )
 
 func PushDecryptStandalone(logger *zap.Logger, rootDir string, inputB64 string, ks accountutils.NativeKeystore) (*pushtypes.DecryptedPush, error) {
 	input, err := base64.RawURLEncoding.DecodeString(inputB64)
 	if err != nil {
-		return nil, errcode.ErrInvalidInput.Wrap(err)
+		return nil, errcode.ErrCode_ErrInvalidInput.Wrap(err)
 	}
 
 	ctx, cancel := context.WithTimeout(context.Background(), time.Second*10)
@@ -33,7 +35,7 @@ func PushDecryptStandalone(logger *zap.Logger, rootDir string, inputB64 string,
 
 	rawPushData, accountData, err := PushDecrypt(ctx, rootDir, input, &PushDecryptOpts{Logger: logger, Keystore: ks})
 	if err != nil {
-		return nil, errcode.ErrPushUnableToDecrypt.Wrap(err)
+		return nil, errcode.ErrCode_ErrPushUnableToDecrypt.Wrap(err)
 	}
 
 	return PushEnrich(rawPushData, accountData, logger)
@@ -41,12 +43,12 @@ func PushDecryptStandalone(logger *zap.Logger, rootDir string, inputB64 string,
 
 func PushEnrich(rawPushData *messengertypes.PushReceivedData, accountData *accounttypes.AccountMetadata, logger *zap.Logger) (*pushtypes.DecryptedPush, error) {
 	if accountData == nil {
-		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("no account metadata specified"))
+		return nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("no account metadata specified"))
 	}
 
-	link, err := bertylinks.InternalLinkToMessage(accountData.AccountID, rawPushData.Interaction.ConversationPublicKey, rawPushData.Interaction.CID)
+	link, err := bertylinks.InternalLinkToMessage(accountData.AccountId, rawPushData.Interaction.ConversationPublicKey, rawPushData.Interaction.Cid)
 	if err != nil {
-		logger.Error("unable to create link for interaction", logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.CID)), zap.Error(err))
+		logger.Error("unable to create link for interaction", logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.Cid)), zap.Error(err))
 		link = bertylinks.LinkInternalPrefix
 	}
 
@@ -61,14 +63,14 @@ func PushEnrich(rawPushData *messengertypes.PushReceivedData, accountData *accou
 	}
 
 	d := &pushtypes.DecryptedPush{
-		AccountID:               accountData.AccountID,
+		AccountId:               accountData.AccountId,
 		AccountName:             accountData.Name,
 		ConversationPublicKey:   rawPushData.Interaction.ConversationPublicKey,
 		ConversationDisplayName: conversationDisplayName,
 		MemberPublicKey:         rawPushData.Interaction.MemberPublicKey,
 		MemberDisplayName:       memberDisplayName,
 		PushType:                pushtypes.DecryptedPush_Unknown,
-		PayloadAttrsJSON:        "{}",
+		PayloadAttrsJson:        "{}",
 		DeepLink:                link,
 		AlreadyReceived:         rawPushData.AlreadyReceived,
 		AccountMuted:            rawPushData.AccountMuted,
@@ -82,7 +84,7 @@ func PushEnrich(rawPushData *messengertypes.PushReceivedData, accountData *accou
 		m := &messengertypes.AppMessage_UserMessage{}
 		err := proto.Unmarshal(rawPushData.Interaction.Payload, m)
 		if err != nil {
-			logger.Error("unable to unmarshal user message", logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.CID)), zap.Error(err))
+			logger.Error("unable to unmarshal user message", logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.Cid)), zap.Error(err))
 			break
 		}
 
@@ -98,18 +100,18 @@ func PushEnrich(rawPushData *messengertypes.PushReceivedData, accountData *accou
 		invitation := &messengertypes.AppMessage_GroupInvitation{}
 		err := proto.Unmarshal(rawPushData.Interaction.Payload, invitation)
 		if err != nil {
-			logger.Error("unable to unmarshal group invitation", logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.CID)), zap.Error(err))
+			logger.Error("unable to unmarshal group invitation", logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.Cid)), zap.Error(err))
 			break
 		}
 
 		link, err := bertylinks.UnmarshalLink(invitation.Link, nil)
 		if err != nil {
-			logger.Error("unable to unmarshal group invitation link", logutil.PrivateString("link", invitation.Link), logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.CID)), zap.Error(err))
+			logger.Error("unable to unmarshal group invitation link", logutil.PrivateString("link", invitation.Link), logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.Cid)), zap.Error(err))
 			break
 		}
 
 		if link.Kind != messengertypes.BertyLink_GroupV1Kind {
-			logger.Error("invalid group invitation link received", logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.CID)), zap.String("link-kind", link.Kind.String()))
+			logger.Error("invalid group invitation link received", logutil.PrivateString("cid", string(rawPushData.ProtocolData.Message.Cid)), zap.String("link-kind", link.Kind.String()))
 			break
 		}
 
@@ -125,16 +127,16 @@ func PushEnrich(rawPushData *messengertypes.PushReceivedData, accountData *accou
 		// TODO: get old values
 
 	case messengertypes.AppMessage_TypeAcknowledge:
-		logger.Debug("received a push notification for an ack, this should not happen", logutil.PrivateString("cid", rawPushData.Interaction.CID))
+		logger.Debug("received a push notification for an ack, this should not happen", logutil.PrivateString("cid", rawPushData.Interaction.Cid))
 
 	default:
-		logger.Debug("unknown message type", zap.String("message-type", rawPushData.Interaction.Type.String()), logutil.PrivateString("cid", rawPushData.Interaction.CID))
+		logger.Debug("unknown message type", zap.String("message-type", rawPushData.Interaction.Type.String()), logutil.PrivateString("cid", rawPushData.Interaction.Cid))
 	}
 
 	if len(payloadAttrs) > 0 {
 		jsoned, err := json.Marshal(payloadAttrs)
 		if err == nil {
-			d.PayloadAttrsJSON = string(jsoned)
+			d.PayloadAttrsJson = string(jsoned)
 		}
 	}
 
@@ -158,7 +160,7 @@ func PushDecrypt(ctx context.Context, rootDir string, input []byte, opts *PushDe
 
 	_, pushSK, err := accountutils.GetDevicePushKeyForPath(path.Join(rootDir, accountutils.DefaultPushKeyFilename), false)
 	if err != nil {
-		return nil, nil, errcode.ErrPushUnableToDecrypt.Wrap(fmt.Errorf("device has no known push key"))
+		return nil, nil, errcode.ErrCode_ErrPushUnableToDecrypt.Wrap(fmt.Errorf("device has no known push key"))
 	}
 
 	accounts, err := accountutils.ListAccounts(ctx, rootDir, opts.Keystore, opts.Logger)
@@ -167,7 +169,7 @@ func PushDecrypt(ctx context.Context, rootDir string, input []byte, opts *PushDe
 	}
 
 	if len(accounts) == 0 {
-		return nil, nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("no accounts found"))
+		return nil, nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("no accounts found"))
 	}
 
 	var errs []error
@@ -178,7 +180,7 @@ func PushDecrypt(ctx context.Context, rootDir string, input []byte, opts *PushDe
 
 			ignoreAccount := false
 			for _, excluded := range opts.ExcludedAccounts {
-				if account.AccountID == excluded {
+				if account.AccountId == excluded {
 					ignoreAccount = true
 					break
 				}
@@ -188,7 +190,7 @@ func PushDecrypt(ctx context.Context, rootDir string, input []byte, opts *PushDe
 				return nil, nil
 			}
 
-			accountDir := accountutils.GetAccountDir(rootDir, account.AccountID)
+			accountDir := accountutils.GetAccountDir(rootDir, account.AccountId)
 			err := accountutils.CreateDataDir(accountDir)
 			if err != nil {
 				return nil, err
@@ -196,14 +198,14 @@ func PushDecrypt(ctx context.Context, rootDir string, input []byte, opts *PushDe
 
 			var storageKey []byte
 			if opts.Keystore != nil {
-				if storageKey, err = accountutils.GetOrCreateStorageKeyForAccount(opts.Keystore, account.AccountID); err != nil {
+				if storageKey, err = accountutils.GetOrCreateStorageKeyForAccount(opts.Keystore, account.AccountId); err != nil {
 					return nil, err
 				}
 			}
 
 			var rootDatastoreSalt []byte
 			if opts.Keystore != nil {
-				if rootDatastoreSalt, err = accountutils.GetOrCreateRootDatastoreSaltForAccount(opts.Keystore, account.AccountID); err != nil {
+				if rootDatastoreSalt, err = accountutils.GetOrCreateRootDatastoreSaltForAccount(opts.Keystore, account.AccountId); err != nil {
 					return nil, err
 				}
 			}
@@ -216,7 +218,7 @@ func PushDecrypt(ctx context.Context, rootDir string, input []byte, opts *PushDe
 
 			var messengerDBSalt []byte
 			if opts.Keystore != nil {
-				if messengerDBSalt, err = accountutils.GetOrCreateMessengerDBSaltForAccount(opts.Keystore, account.AccountID); err != nil {
+				if messengerDBSalt, err = accountutils.GetOrCreateMessengerDBSaltForAccount(opts.Keystore, account.AccountId); err != nil {
 					return nil, err
 				}
 			}
@@ -228,22 +230,26 @@ func PushDecrypt(ctx context.Context, rootDir string, input []byte, opts *PushDe
 			defer dbCleanup()
 
 			wrappedDB := messengerdb.NewDBWrapper(db, opts.Logger)
+			dbFetcher := dbfetcher.NewDBFetcher(account.PublicKey, wrappedDB)
 
-			pushHandler, err := NewPushHandler(&PushHandlerOpts{
-				Logger:        opts.Logger,
-				RootDatastore: rootDS,
-				PushKey:       pushSK,
+			weshClient, err := weshnet.NewOutOfStoreMessageServiceClient(weshnet.WithRootDatastore(rootDS), weshnet.WithLogger(opts.Logger))
+			if err != nil {
+				return nil, errcode.ErrCode_ErrInternal.Wrap(fmt.Errorf("unable to initialize weshnet client: %w", err))
+			}
+
+			pushHandler, err := NewPushHandler(weshClient, dbFetcher, pushSK, &PushHandlerOpts{
+				Logger: opts.Logger,
 			})
 			if err != nil {
-				return nil, errcode.ErrInternal.Wrap(fmt.Errorf("unable to initialize push handler: %w", err))
+				return nil, errcode.ErrCode_ErrInternal.Wrap(fmt.Errorf("unable to initialize push handler: %w", err))
 			}
 
 			evtHandler := messengerpayloads.NewEventHandler(ctx, wrappedDB, nil, messengertypes.NewPostActionsServiceNoop(), opts.Logger, nil, false)
-			pushReceiver := NewPushReceiver(pushHandler, evtHandler, wrappedDB, opts.Logger)
+			pushReceiver := NewPushReceiver(pushHandler, evtHandler, dbFetcher, opts.Logger)
 
 			reply, err = pushReceiver.PushReceive(ctx, input)
 			if err != nil {
-				opts.Logger.Warn("unable to decrypt push", logutil.PrivateString("account-id", account.AccountID), zap.Error(err))
+				opts.Logger.Warn("unable to decrypt push", logutil.PrivateString("account-id", account.AccountId), zap.Error(err))
 				return nil, err
 			}
 
@@ -259,9 +265,9 @@ func PushDecrypt(ctx context.Context, rootDir string, input []byte, opts *PushDe
 	}
 
 	if len(errs) == 0 {
-		return nil, nil, errcode.ErrInternal.Wrap(fmt.Errorf("no account can decrypt the received push message"))
+		return nil, nil, errcode.ErrCode_ErrInternal.Wrap(fmt.Errorf("no account can decrypt the received push message"))
 	}
 
 	// only returning the first error
-	return nil, nil, errcode.ErrPushUnableToDecrypt.Wrap(errs[0])
+	return nil, nil, errcode.ErrCode_ErrPushUnableToDecrypt.Wrap(errs[0])
 }
