@@ -10,19 +10,19 @@ import (
 	"go.uber.org/zap"
 	"golang.org/x/crypto/curve25519"
 	"golang.org/x/crypto/nacl/box"
+	"google.golang.org/protobuf/proto"
 
 	"berty.tech/berty/v2/go/pkg/errcode"
-	"berty.tech/weshnet/pkg/cryptoutil"
-	weshnet_errcode "berty.tech/weshnet/pkg/errcode"
-	"berty.tech/weshnet/pkg/logutil"
-	"berty.tech/weshnet/pkg/protocoltypes"
-	"berty.tech/weshnet/pkg/pushtypes"
+	"berty.tech/berty/v2/go/pkg/pushtypes"
+	"berty.tech/weshnet/v2/pkg/cryptoutil"
+	"berty.tech/weshnet/v2/pkg/logutil"
+	"berty.tech/weshnet/v2/pkg/protocoltypes"
 )
 
 const ServicePushPayloadMax = 4096 // FIXME: find an appropriate value
 
 type PushDispatcher interface {
-	Dispatch(payload []byte, receiver *protocoltypes.PushServiceReceiver) error
+	Dispatch(payload []byte, receiver *pushtypes.PushServiceReceiver) error
 	BundleID() string
 	TokenType() pushtypes.PushServiceTokenType
 }
@@ -48,22 +48,30 @@ func (d *pushService) ServerInfo(_ context.Context, _ *pushtypes.PushServiceServ
 	}, nil
 }
 
-func (d *pushService) Send(ctx context.Context, request *pushtypes.PushServiceSend_Request) (*pushtypes.PushServiceSend_Reply, error) {
+func (d *pushService) Send(_ context.Context, request *pushtypes.PushServiceSend_Request) (*pushtypes.PushServiceSend_Reply, error) {
 	if len(request.Receivers) == 0 {
-		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("no receivers supplied"))
+		return nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("no receivers supplied"))
 	}
 
-	if len(request.Envelope.Nonce) != cryptoutil.NonceSize {
-		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("invalid nonce size"))
+	if len(request.Envelope) == 0 {
+		return nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("no envelope supplied"))
 	}
 
-	if len(request.Envelope.Box) > ServicePushPayloadMax {
-		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("payload too large"))
+	envelope := &protocoltypes.OutOfStoreMessageEnvelope{}
+	if err := proto.Unmarshal(request.Envelope, envelope); err != nil {
+		return nil, errcode.ErrCode_ErrDeserialization.Wrap(fmt.Errorf("unable to unmarshal envelope: %w", err))
 	}
 
-	pushPayload, err := request.Envelope.Marshal()
-	if err != nil {
-		return nil, errcode.ErrSerialization.Wrap(err)
+	if len(envelope.Nonce) != cryptoutil.NonceSize {
+		return nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("invalid nonce size"))
+	}
+
+	if len(envelope.Box) > ServicePushPayloadMax {
+		return nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("payload too large"))
+	}
+
+	if len(envelope.GroupReference) == 0 {
+		return nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("no group reference supplied"))
 	}
 
 	wg := sync.WaitGroup{}
@@ -72,7 +80,7 @@ func (d *pushService) Send(ctx context.Context, request *pushtypes.PushServiceSe
 	errCount := int32(0)
 	for i, receiver := range request.Receivers {
 		go func(i int, receiver *pushtypes.PushServiceOpaqueReceiver) {
-			if err := d.sendSingle(pushPayload, receiver); err != nil {
+			if err := d.sendSingle(request.Envelope, receiver); err != nil {
 				d.logger.Warn("unable to send a push", zap.Int("index", i), zap.Error(err))
 				atomic.AddInt32(&errCount, 1)
 			} else {
@@ -93,7 +101,7 @@ func (d *pushService) Send(ctx context.Context, request *pushtypes.PushServiceSe
 	return &pushtypes.PushServiceSend_Reply{}, nil
 }
 
-func (d *pushService) decodeOpaqueReceiver(receiver *pushtypes.PushServiceOpaqueReceiver) (*protocoltypes.PushServiceReceiver, error) {
+func (d *pushService) decodeOpaqueReceiver(receiver *pushtypes.PushServiceOpaqueReceiver) (*pushtypes.PushServiceReceiver, error) {
 	return InternalDecodeOpaqueReceiver(d.publicKey, d.privateKey, d.dispatchers, receiver)
 }
 
@@ -101,68 +109,66 @@ func (d *pushService) encryptPushPayloadForReceiver(rawPayload, recipientPublicK
 	return InternalEncryptPushPayloadForReceiver(d.privateKey, rawPayload, recipientPublicKey)
 }
 
-func InternalDecodeOpaqueReceiver(publicKey *[cryptoutil.KeySize]byte, privateKey *[cryptoutil.KeySize]byte, dispatchers map[string]PushDispatcher, receiver *pushtypes.PushServiceOpaqueReceiver) (*protocoltypes.PushServiceReceiver, error) {
+func InternalDecodeOpaqueReceiver(publicKey *[cryptoutil.KeySize]byte, privateKey *[cryptoutil.KeySize]byte, dispatchers map[string]PushDispatcher, receiver *pushtypes.PushServiceOpaqueReceiver) (*pushtypes.PushServiceReceiver, error) {
 	receiverBytes, ok := box.OpenAnonymous(nil, receiver.OpaqueToken, publicKey, privateKey)
 	if !ok {
-		return nil, errcode.ErrCryptoDecrypt.Wrap(fmt.Errorf("unable to decrypt push identifier"))
+		return nil, errcode.ErrCode_ErrCryptoDecrypt.Wrap(fmt.Errorf("unable to decrypt push identifier"))
 	}
 
-	pushReceiver := &protocoltypes.PushServiceReceiver{}
-	if err := pushReceiver.Unmarshal(receiverBytes); err != nil {
-		return nil, errcode.ErrDeserialization.Wrap(fmt.Errorf("unable to unmarshal push identifier: %w", err))
+	pushReceiver := &pushtypes.PushServiceReceiver{}
+	if err := proto.Unmarshal(receiverBytes, pushReceiver); err != nil {
+		return nil, errcode.ErrCode_ErrDeserialization.Wrap(fmt.Errorf("unable to unmarshal push identifier: %w", err))
 	}
 
-	if _, ok := dispatchers[PushDispatcherKey(pushReceiver.TokenType, pushReceiver.BundleID)]; !ok {
-		return nil, weshnet_errcode.ErrPushUnknownProvider.Wrap(fmt.Errorf("unsupported bundle id"))
+	if _, ok := dispatchers[PushDispatcherKey(pushReceiver.TokenType, pushReceiver.BundleId)]; !ok {
+		return nil, errcode.ErrCode_ErrPushUnknownProvider.Wrap(fmt.Errorf("unsupported bundle id"))
 	}
 
 	return pushReceiver, nil
 }
 
 func InternalEncryptPushPayloadForReceiver(privateKey *[cryptoutil.KeySize]byte, rawPayload, recipientPublicKey []byte) ([]byte, error) {
-	// FIXME(push): `pushtypes.PushExposedData` doesn't exist anymore
+	nonce, err := cryptoutil.GenerateNonce()
+	if err != nil {
+		return nil, errcode.ErrCode_ErrCryptoNonceGeneration.Wrap(err)
+	}
 
-	// nonce, err := cryptoutil.GenerateNonce()
-	// if err != nil {
-	// 	return nil, errcode.ErrCryptoNonceGeneration.Wrap(err)
-	// }
+	receiverKey, err := cryptoutil.KeySliceToArray(recipientPublicKey)
+	if err != nil {
+		return nil, errcode.ErrCode_ErrSerialization.Wrap(err)
+	}
 
-	// receiverKey, err := cryptoutil.KeySliceToArray(recipientPublicKey)
-	// if err != nil {
-	// 	return nil, errcode.ErrSerialization.Wrap(err)
-	// }
+	boxed := box.Seal(nil, rawPayload, nonce, receiverKey, privateKey)
 
-	// boxed := box.Seal(nil, rawPayload, nonce, receiverKey, privateKey)
+	payloadBytes, err := proto.Marshal(&pushtypes.OutOfStoreExposedData{
+		Nonce: nonce[:],
+		Box:   boxed,
+	})
+	if err != nil {
+		return nil, errcode.ErrCode_ErrSerialization.Wrap(err)
+	}
 
-	// payloadBytes, err := (&pushtypes.PushExposedData{
-	// 	Nonce: nonce[:],
-	// 	Box:   boxed,
-	// }).Marshal()
-	// if err != nil {
-	// 	return nil, errcode.ErrSerialization.Wrap(err)
-	// }
-
-	return []byte{}, nil
+	return payloadBytes, nil
 }
 
 func (d *pushService) sendSingle(rawPayload []byte, receiver *pushtypes.PushServiceOpaqueReceiver) error {
 	pushReceiver, err := d.decodeOpaqueReceiver(receiver)
 	if err != nil {
-		return errcode.ErrCryptoDecrypt.Wrap(err)
+		return errcode.ErrCode_ErrCryptoDecrypt.Wrap(err)
 	}
 
-	dispatcher, ok := d.dispatchers[PushDispatcherKey(pushReceiver.TokenType, pushReceiver.BundleID)]
+	dispatcher, ok := d.dispatchers[PushDispatcherKey(pushReceiver.TokenType, pushReceiver.BundleId)]
 	if !ok {
-		return weshnet_errcode.ErrPushUnknownProvider.Wrap(fmt.Errorf("unsupported %s", PushDispatcherKey(pushReceiver.TokenType, pushReceiver.BundleID)))
+		return errcode.ErrCode_ErrPushUnknownProvider.Wrap(fmt.Errorf("unsupported %s", PushDispatcherKey(pushReceiver.TokenType, pushReceiver.BundleId)))
 	}
 
 	payloadBytes, err := d.encryptPushPayloadForReceiver(rawPayload, pushReceiver.RecipientPublicKey)
 	if err != nil {
-		return errcode.ErrCryptoEncrypt.Wrap(err)
+		return errcode.ErrCode_ErrCryptoEncrypt.Wrap(err)
 	}
 
 	if err := dispatcher.Dispatch(payloadBytes, pushReceiver); err != nil {
-		return weshnet_errcode.ErrPushProvider.Wrap(err)
+		return errcode.ErrCode_ErrPushProvider.Wrap(err)
 	}
 
 	return nil
@@ -186,11 +192,11 @@ func newPushService(privateKey *[cryptoutil.KeySize]byte, dispatchers []PushDisp
 	var err error
 
 	if privateKey == nil {
-		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("no private key provided"))
+		return nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("no private key provided"))
 	}
 
 	if len(dispatchers) == 0 {
-		return nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("no push dispatchers provided"))
+		return nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("no push dispatchers provided"))
 	}
 
 	if logger == nil {
@@ -228,13 +234,13 @@ func PushServiceGenerateDispatchers(dispatchers []PushDispatcher) (map[string]Pu
 		tokenType := dispatcher.TokenType()
 
 		if _, ok := serviceDispatchers[PushDispatcherKey(tokenType, bundleID)]; ok {
-			return nil, nil, errcode.ErrInvalidInput.Wrap(fmt.Errorf("pushservice: %s app %s registered twice", tokenType.String(), bundleID))
+			return nil, nil, errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("pushservice: %s app %s registered twice", tokenType.String(), bundleID))
 		}
 
 		serviceDispatchers[PushDispatcherKey(tokenType, bundleID)] = dispatcher
 
 		serviceSupportedTypes = append(serviceSupportedTypes, &pushtypes.PushServiceSupportedTokenType{
-			AppBundleID: bundleID,
+			AppBundleId: bundleID,
 			TokenType:   tokenType,
 		})
 	}
