@@ -3,7 +3,6 @@ package bertyreplication_test
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"testing"
 	"time"
@@ -18,19 +17,19 @@ import (
 
 	"berty.tech/berty/v2/go/internal/datastoreutil"
 	"berty.tech/berty/v2/go/internal/messengerutil"
+	"berty.tech/berty/v2/go/pkg/authtypes"
+	"berty.tech/berty/v2/go/pkg/bertyauth"
 	"berty.tech/berty/v2/go/pkg/bertyreplication"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	orbitdb "berty.tech/go-orbit-db"
 	"berty.tech/go-orbit-db/iface"
 	"berty.tech/go-orbit-db/stores"
-	"berty.tech/weshnet"
-	"berty.tech/weshnet/pkg/authtypes"
-	"berty.tech/weshnet/pkg/bertyauth"
-	"berty.tech/weshnet/pkg/ipfsutil"
-	"berty.tech/weshnet/pkg/protocoltypes"
-	"berty.tech/weshnet/pkg/replicationtypes"
-	"berty.tech/weshnet/pkg/testutil"
-	"berty.tech/weshnet/pkg/tinder"
+	"berty.tech/weshnet/v2"
+	"berty.tech/weshnet/v2/pkg/ipfsutil"
+	"berty.tech/weshnet/v2/pkg/protocoltypes"
+	"berty.tech/weshnet/v2/pkg/replicationtypes"
+	"berty.tech/weshnet/v2/pkg/testutil"
+	"berty.tech/weshnet/v2/pkg/tinder"
 )
 
 func TestNewReplicationService(t *testing.T) {
@@ -106,7 +105,10 @@ func TestReplicationService_GroupRegister(t *testing.T) {
 
 	db := bertyreplication.DBForTests(t, zap.NewNop())
 
-	repl, _ := bertyreplication.TestHelperNewReplicationService(ctx, t, nil, mn, msrv, ds, db)
+	logger, cleanup := testutil.Logger(t)
+	defer cleanup()
+
+	repl, _ := bertyreplication.TestHelperNewReplicationService(ctx, t, logger, mn, msrv, ds, db)
 
 	g, _, err := weshnet.NewGroupMultiMember()
 	require.NoError(t, err)
@@ -119,14 +121,14 @@ func TestReplicationService_GroupRegister(t *testing.T) {
 
 	err = repl.GroupRegister("token", "issuer", replGroup)
 	require.Error(t, err)
-	require.True(t, errcode.Is(err, errcode.ErrDBEntryAlreadyExists))
+	require.True(t, errcode.Is(err, errcode.ErrCode_ErrDBEntryAlreadyExists))
 
 	err = repl.GroupRegister("token2", "issuer", replGroup)
 	require.NoError(t, err)
 
 	err = repl.GroupRegister("token2", "issuer", replGroup)
 	require.Error(t, err)
-	require.True(t, errcode.Is(err, errcode.ErrDBEntryAlreadyExists))
+	require.True(t, errcode.Is(err, errcode.ErrCode_ErrDBEntryAlreadyExists))
 
 	err = repl.Close()
 	require.NoError(t, err)
@@ -374,7 +376,7 @@ func TestReplicationService_Flow(t *testing.T) {
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
 
-	pathBase, err := ioutil.TempDir("", "odb_replication_service")
+	pathBase, err := os.MkdirTemp("", "odb_replication_service")
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -472,13 +474,13 @@ func TestReplicationService_Flow(t *testing.T) {
 
 		evts1, err := m1.ListEvents(ctx, nil, nil, false)
 		require.NoError(t, err)
-		ops1 := testutil.TestFilterAppMetadata(t, evts1)
+		ops1 := testutil.TestFilterGroupMetadataPayloadSent(t, evts1)
 		require.NoError(t, err)
 		assert.Equal(t, 2, len(ops1))
 
 		evts2, err := m2.ListEvents(ctx, nil, nil, false)
 		require.NoError(t, err)
-		ops2 := testutil.TestFilterAppMetadata(t, evts2)
+		ops2 := testutil.TestFilterGroupMetadataPayloadSent(t, evts2)
 		require.NoError(t, err)
 		assert.Equal(t, 2, len(ops2))
 	}
@@ -535,7 +537,7 @@ func TestReplicationService_InvalidFlow(t *testing.T) {
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
 
-	pathBase, err := ioutil.TempDir("", "odb_replication_service")
+	pathBase, err := os.MkdirTemp("", "odb_replication_service")
 	if err != nil {
 		t.Fatal(err)
 	}
