@@ -14,7 +14,7 @@ type PhoneCodeSenderMockService struct {
 	Logger *zap.Logger
 }
 
-func (m *PhoneCodeSenderMockService) SendVerificationCode(ctx context.Context, in SendVerificationCodeData) error {
+func (m *PhoneCodeSenderMockService) SendVerificationCode(_ context.Context, in SendVerificationCodeData) error {
 	logger := m.Logger
 	if logger == nil {
 		logger = zap.NewNop()
@@ -25,14 +25,14 @@ func (m *PhoneCodeSenderMockService) SendVerificationCode(ctx context.Context, i
 	return nil
 }
 
-func (m *PhoneCodeSenderMockService) ValidateIdentifier(ctx context.Context, rawIdentifier string) (string, error) {
+func (m *PhoneCodeSenderMockService) ValidateIdentifier(_ context.Context, rawIdentifier string) (string, error) {
 	num, err := phonenumbers.Parse(rawIdentifier, "")
 	if err != nil {
-		return "", errcode.ErrInvalidInput.Wrap(err)
+		return "", errcode.ErrCode_ErrInvalidInput.Wrap(err)
 	}
 
 	if !phonenumbers.IsValidNumber(num) {
-		return "", errcode.ErrInvalidInput.Wrap(fmt.Errorf("phone number is invalid"))
+		return "", errcode.ErrCode_ErrInvalidInput.Wrap(fmt.Errorf("phone number is invalid"))
 	}
 
 	return fmt.Sprintf("tel:%s", phonenumbers.Format(num, phonenumbers.E164)), nil
