@@ -19,12 +19,13 @@ struct BridgeError: LocalizedError {
 
 @objc(GoBridge)
 class GoBridge: NSObject {
-    let logger = LoggerDriver("tech.berty", "react")
+    let logger = BertyLogger("tech.berty.react")
 
     // protocol
     var bridgeMessenger: BertybridgeBridge?
     var remoteBridge: BertybridgeRemoteBridge?
     var serviceClient: BertybridgeServiceClientProtocol?
+    var connectivityDriver = ConnectivityDriver()
     let appRootDir: String
     let sharedRootDir: String
 
@@ -43,28 +44,28 @@ class GoBridge: NSObject {
     }
 
     deinit {
-      do {
-          if self.bridgeMessenger != nil {
-              try self.bridgeMessenger?.close()
-              self.bridgeMessenger = nil
-          }
-          if self.remoteBridge != nil {
-              try self.remoteBridge?.close()
-              self.remoteBridge = nil
-          }
-          self.serviceClient = nil
-      } catch let error as NSError {
-        NSLog("\(String(describing: error.code))")
-      }
+        do {
+            if self.bridgeMessenger != nil {
+                try self.bridgeMessenger?.close()
+                self.bridgeMessenger = nil
+            }
+            if self.remoteBridge != nil {
+                try self.remoteBridge?.close()
+                self.remoteBridge = nil
+            }
+            self.serviceClient = nil
+        } catch let error as NSError {
+            self.logger.error("\(String(describing: error.code))")
+        }
     }
 
     @objc func constantsToExport() -> [AnyHashable : Any]! {
-#if DEBUG_LOGS
-      let debug = true;
-#else
-      let debug = false;
-#endif
-      return ["debug": debug];
+        #if DEBUG_LOGS
+        let debug = true;
+        #else
+        let debug = false;
+        #endif
+        return ["debug": debug];
     }
 
     @objc func clearStorage(_ resolve: @escaping RCTPromiseResolveBlock, reject: @escaping RCTPromiseRejectBlock) {
@@ -85,13 +86,9 @@ class GoBridge: NSObject {
     @objc func log(_ opts: NSDictionary) {
         #if !CFG_APPSTORE
         if let message = opts["message"] as? String {
-            let type = opts["level"] as? String ?? "info"
+            let level = opts["level"] as? String ?? "INFO"
 
-            // set log level
-            let level = Level(rawValue: type.uppercased()) ?? Level.info
-
-            // log
-            self.logger.print(message as NSString, level: level, category: "react-native")
+            self.logger.log(BertyLogger.LogLevel(rawValue: level.uppercased()) ?? .INFO, message)
         }
         #endif
     }
@@ -111,8 +108,6 @@ class GoBridge: NSObject {
                 throw NSError(domain: "tech.berty.gobridge", code: 2, userInfo: [NSLocalizedDescriptionKey : "unable to create config"])
             }
 
-            config.setLoggerDriver(LoggerDriver("tech.berty", "gomobile"))
-
             // get user preferred languages
             let preferredLanguages: String = Locale.preferredLanguages.joined(separator: ",")
 
@@ -147,6 +142,8 @@ class GoBridge: NSObject {
             config.setAppRootDir(self.appRootDir)
             config.setSharedRootDir(self.sharedRootDir)
 
+            config.setConnectivityDriver(self.connectivityDriver);
+
             let bridgeMessenger = BertybridgeNewBridge(config, &err)
             if err != nil {
                 throw err!
@@ -155,6 +152,8 @@ class GoBridge: NSObject {
             self.bridgeMessenger = bridgeMessenger
             self.serviceClient = bridgeMessenger // bridgeMessenger implements ServiceClient interface
 
+            BertyLogger.useBridge(self.bridgeMessenger)
+
             resolve(true)
         } catch let error as NSError {
             reject("\(String(describing: error.code))", error.userInfo.description, error)
@@ -172,8 +171,6 @@ class GoBridge: NSObject {
               throw NSError(domain: "tech.berty.gobridge", code: 2, userInfo: [NSLocalizedDescriptionKey : "unable to create config"])
           }
 
-          config.setLoggerDriver(LoggerDriver("tech.berty", "gomobile"))
-
           // Disable iOS backup
           var values = URLResourceValues()
           values.isExcludedFromBackup = true
@@ -236,12 +233,12 @@ class GoBridge: NSObject {
 
     @objc func getProtocolAddr(_ resolve: @escaping RCTPromiseResolveBlock, reject: @escaping RCTPromiseRejectBlock) {
         do {
-          if self.bridgeMessenger == nil {
-              throw NSError(domain: "tech.berty.gobridge", code: 4, userInfo: [NSLocalizedDescriptionKey : "bridgeMessenger isn't started"])
-          }
+            if self.bridgeMessenger == nil {
+                throw NSError(domain: "tech.berty.gobridge", code: 4, userInfo: [NSLocalizedDescriptionKey : "bridgeMessenger isn't started"])
+            }
 
-          let addr: [String] = []
-          resolve(addr)
+            let addr: [String] = []
+            resolve(addr)
         } catch let error as NSError {
             reject("\(String(describing: error.code))", error.userInfo.description, error)
         }
