@@ -5,8 +5,7 @@ import { ButtonDefProps, IconNameProps } from '../interfaces'
 import { ErrorButtonPriv } from './ErrorButton.priv'
 import { ErrorTextPriv } from './ErrorText.priv'
 
-// eslint-disable-next-line @typescript-eslint/no-unused-vars
-const ErrorButtonIconRight: React.FC<ButtonDefProps & IconNameProps> = props => {
+export const ErrorButtonIconRight: React.FC<ButtonDefProps & IconNameProps> = props => {
 	return (
 		<ErrorButtonPriv {...props}>
 			<ErrorTextPriv disabled={!!props.disabled}>{props.children}</ErrorTextPriv>
