@@ -1,6 +1,6 @@
 export { PrimaryButton } from './primary/PrimaryButton'
 export { PrimaryAltButton } from './primary/PrimaryAltButton'
-export { PrimaryButtonIconLeft } from './primary/PrimaryButtonIconLeft'
+// export { PrimaryButtonIconLeft } from './primary/PrimaryButtonIconLeft'
 // export { PrimaryButtonIconRight } from './primary/PrimaryButtonIconRight'
 export { SecondaryButton } from './secondary/SecondaryButton'
 export { SecondaryAltButton } from './secondary/SecondaryAltButton'
@@ -14,6 +14,5 @@ export { TertiaryButtonIconLeft } from './tertiary/TertiaryButtonIconLeft'
 export { ErrorButtonIconLeft } from './error/ErrorButtonIconLeft'
 // export { ErrorButtonIconRight } from './error/ErrorButtonIconRight'
 // export { VerticalButtons } from './vertical/VerticalButtons'
-export { TwoHorizontalButtons } from './horizontal/TwoHorizontalButtons'
 export { PrimaryFloatingButton } from './floating-buttons/primary/PrimaryFloatingButton'
 // export { SecondaryFloatingButton } from './floating-buttons/secondary/SecondaryFloatingButton'
