@@ -1,3 +1,3 @@
 export interface NetworkProps {
-	accessibilityLabel?: string
+	testID?: string
 }
