@@ -18,6 +18,6 @@ export const TextPriv: React.FC<{}> = props => {
 
 const styles = StyleSheet.create({
 	container: {
-		width: '75%',
+		flexShrink: 1,
 	},
 })
