@@ -1,14 +1,13 @@
 import React from 'react'
-import { TouchableOpacity, View, Text } from 'react-native'
+import { TouchableOpacity, View } from 'react-native'
 
-import { useStyles } from '@berty-tech/styles'
-import { useThemeColor } from '@berty-tech/store/hooks'
+import { useStyles } from '@berty/contexts/styles'
 
+import { UnifiedText } from '../shared-components/UnifiedText'
 import { useStylesNotification, NotificationTmpLogo } from './common'
 
 const Basic: React.FC<any> = ({ onPress, onClose, title, message }) => {
-	const [{ text }] = useStyles()
-	const colors = useThemeColor()
+	const { text } = useStyles()
 	const _styles = useStylesNotification()
 
 	return (
@@ -23,12 +22,12 @@ const Basic: React.FC<any> = ({ onPress, onClose, title, message }) => {
 			<View style={_styles.innerTouchable}>
 				<NotificationTmpLogo />
 				<View style={_styles.titleAndTextWrapper}>
-					<Text numberOfLines={1} style={[text.bold.medium, { color: colors['main-text'] }]}>
+					<UnifiedText numberOfLines={1} style={[text.bold]}>
 						{title}
-					</Text>
-					<Text numberOfLines={1} ellipsizeMode='tail' style={{ color: colors['main-text'] }}>
+					</UnifiedText>
+					<UnifiedText numberOfLines={1} ellipsizeMode='tail'>
 						{message}
-					</Text>
+					</UnifiedText>
 				</View>
 			</View>
 		</TouchableOpacity>
