@@ -2,7 +2,7 @@ import React from 'react'
 import { Text, TextProps } from 'react-native'
 
 import { useStyles } from '@berty/contexts/styles'
-import { useThemeColor } from '@berty/store'
+import { useThemeColor } from '@berty/hooks'
 
 export const UnifiedText: React.FC<TextProps> = props => {
 	const { children, style } = props
