@@ -13,7 +13,9 @@ type GoLoggerOpts = {
 export interface GoBridgeInterface {
 	log(opts: GoLoggerOpts): void
 	initBridge(): Promise<void>
+	initBridgeRemote(address: string): Promise<void>
 	clearStorage(): Promise<void>
 	closeBridge(): Promise<void>
 	invokeBridgeMethod(method: string, b64message: string): Promise<string>
+	connectService(serviceName: string, address: string): Promise<void>
 }
