@@ -12,6 +12,7 @@ import { UnifiedText } from '@berty/components/shared-components/UnifiedText'
 import { useStyles } from '@berty/contexts/styles'
 import { bertyMethodsHooks, useAppDispatch, useConversation, useThemeColor } from '@berty/hooks'
 import { dispatch as navDispatch } from '@berty/navigation/rootRef'
+import * as testIDs from '@berty/utils/testing/testIDs.json'
 
 import InvalidScan from './InvalidScan'
 
@@ -85,13 +86,15 @@ export const ManageGroupInvitation: React.FC<{
 			)
 		}
 	}, [done, error, dispatch])
+
 	if (convId) {
 		navigationDispatch(
 			CommonActions.reset({
+				index: 1,
 				routes: [
 					{ name: 'Chat.Home' },
 					{
-						name: 'Chat.Group',
+						name: 'Chat.MultiMember',
 						params: {
 							convId,
 						},
@@ -103,9 +106,9 @@ export const ManageGroupInvitation: React.FC<{
 	if (error) {
 		return <InvalidScan type={type} error={error} />
 	}
-
 	return (
 		<View
+			accessibilityLabel='ManageDeepLink-ManageGroupInvitation'
 			style={[{ justifyContent: 'center', alignItems: 'center', height: '100%' }, padding.medium]}
 		>
 			<View
@@ -200,7 +203,7 @@ export const ManageGroupInvitation: React.FC<{
 							border.radius.small,
 							{ backgroundColor: colors['positive-asset'] },
 						]}
-						accessibilityLabel={t('modals.group-invitation.join')}
+						testID={testIDs['group-join']}
 					>
 						<UnifiedText
 							style={{
