@@ -3,14 +3,13 @@ import { useFocusEffect } from '@react-navigation/native'
 import React, { useState } from 'react'
 import { useTranslation } from 'react-i18next'
 import { Keyboard, TouchableOpacity, View, Platform } from 'react-native'
-import AndroidKeyboardAdjust from 'react-native-android-keyboard-adjust'
+import AndroidKeyboardAdjust from 'rn-android-keyboard-adjust'
 
 import beapi from '@berty/api'
 import { ContactAvatar } from '@berty/components/avatars'
 import { ChatDate } from '@berty/components/chat/ChatDate'
 import { ChatFooter } from '@berty/components/chat/footer/ChatFooter'
 import { MessageList } from '@berty/components/chat/MessageList'
-import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
 import { useStyles } from '@berty/contexts/styles'
 import {
 	useContact,
@@ -24,10 +23,6 @@ import { CustomTitleStyle } from '@berty/navigation/stacks'
 import { pbDateToNum } from '@berty/utils/convert/time'
 import { IOSOnlyKeyboardAvoidingView } from '@berty/utils/react-native/keyboardAvoiding'
 
-//
-// Chat
-//
-
 const NT = beapi.messenger.StreamEvent.Notified.Type
 
 export const OneToOne: ScreenFC<'Chat.OneToOne'> = React.memo(
@@ -45,7 +40,6 @@ export const OneToOne: ScreenFC<'Chat.OneToOne'> = React.memo(
 		})
 
 		const { opacity, flex } = useStyles()
-		const { scaleSize } = useAppDimensions()
 		const colors = useThemeColor()
 		useReadEffect(params?.convId, 1000)
 		const { t } = useTranslation()
@@ -94,13 +88,17 @@ export const OneToOne: ScreenFC<'Chat.OneToOne'> = React.memo(
 						style={[!contact ? opacity(0.5) : null]}
 						onPress={() => navigate('Chat.OneToOneSettings', { convId: params.convId })}
 					>
-						<ContactAvatar size={40 * scaleSize} publicKey={conv?.contactPublicKey} />
+						<ContactAvatar size={40} publicKey={conv?.contactPublicKey} />
 					</TouchableOpacity>
 				),
 			})
 		})
 
-		if (Platform.OS === 'android' && !keyboardIsHidden) {
+		if (
+			(Platform.OS === 'android' && !keyboardIsHidden) ||
+			!params.convId ||
+			!params.convId.length
+		) {
 			return null
 		}
 
@@ -115,7 +113,8 @@ export const OneToOne: ScreenFC<'Chat.OneToOne'> = React.memo(
 						<MessageList
 							id={params.convId}
 							scrollToMessage={params.scrollToMessage || '0'}
-							{...{ setStickyDate, setShowStickyDate }}
+							setStickyDate={setStickyDate}
+							setShowStickyDate={setShowStickyDate}
 						/>
 						<ChatFooter
 							convPK={params.convId}
@@ -126,7 +125,7 @@ export const OneToOne: ScreenFC<'Chat.OneToOne'> = React.memo(
 							<View
 								style={{
 									position: 'absolute',
-									top: 110 * scaleSize, // TODO Redefine
+									top: 110,
 									left: 0,
 									right: 0,
 								}}
